*============================================================================;
*  Title:
*         Format Library for Inpatient Quality Indicators Program;
*
*  Description:
*          FORMAT LIB FOR AHRQ INPATIENT QUALITY INDICATORS;
*
*          >>>  VERSION 2.1 (revision 2), September 2003 <<<
*
*          Note:  Codes valid from 10/1/1994 to 9/30/2003
*
*============================================================================;
FILENAME CONTROL 'c:\pathname\CONTROL_IQI.SAS';  *<===USER MUST modify;

%INCLUDE CONTROL;

PROC FORMAT DDNAME=library;

 /* -------------------------------------------------------------- */
 /* --- FORMATS FOR STRATIFIERS ---------------------------------- */
 /* -------------------------------------------------------------- */

 /* --- FORMAT FOR SEX CATEGORY ---------------------------------- */
VALUE $SEXCAT
 'M' = 'Male'
 'F' = 'Female'
  ;

 /* --- FORMAT FOR AGE CATEGORY ---------------------------------- */
VALUE $AGECAT
 '1' = '0 to 17'
 '2' = '18 to 39'
 '3' = '40 to 64'
 '4' = '65+'
  ;

 /* --- FORMAT FOR RACE CATEGORY --------------------------------- */
VALUE $RACECAT
 'W' = 'White'
 'B' = 'Black'
 'H' = 'Hispanic'
 'O' = 'Other'
  ;

 /* --- FORMAT FOR PAYER CATEGORY ---------------------------------- */
VALUE $PAYCAT
 'M' = 'Medicare'
 'D' = 'Medicaid'
 'P' = 'Private'
 'S' = 'Self Pay'
 'O' = 'Other'
  ;

 * -------------------------------------------------------------- ;
 * --- IQI DEFINING FORMATS ------------------------------------- ;
 * -------------------------------------------------------------- ;

 * -------------------------------------------------------------- ;
 * --- FORMATS - PROVIDER LEVEL VOLUME INDICATORS --------------- ;
 * -------------------------------------------------------------- ;

 /* ---------------------------------------- */
 /* Esophageal Cancer Resection (PRESOP)     */
 /*   Volume Indicator / IQI #1              */
 /*   Mortality (post-op) Indicator / IQI #8 */
 /* ---------------------------------------- */

 /* Esophageal resection */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRESOPP
'4240' = '1' /* ESOPHAGECTOMY NOS */
'4241' = '1' /* PARTIAL ESOPHAGECTOMY */
'4242' = '1' /* TOTAL ESOPHAGECTOMY */
OTHER  = '0' ;

 /* Include Only: Esophageal Cancer */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRESOPD
'1500 ' = '1'  /* MAL NEO CERVICAL ESOPHAG */
'1501 ' = '1'  /* MAL NEO THORACIC ESOPHAG */
'1502 ' = '1'  /* MAL NEO ABDOMIN ESOPHAG */
'1503 ' = '1'  /* MAL NEO UPPER 3RD ESOPH */
'1504 ' = '1'  /* MAL NEO MIDDLE 3RD ESOPH */
'1505 ' = '1'  /* MAL NEO LOWER 3RD ESOPH */
'1508 ' = '1'  /* MAL NEO ESOPHAGUS NEC */
'1509 ' = '1'  /* MAL NEO ESOPHAGUS NOS */
OTHER  = '0' ;

 /* ---------------------------------------- */
 /* Pancreatic Cancer Reseciton (PRPANC)     */
 /*   Volume Indicator / IQI #2              */
 /*   Mortality (post-op) Indicator / IQI #9 */
 /* ---------------------------------------- */

 /* Pancreatic Resection */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRPANCP
'526 ' = '1' /* TOTAL PANCREATECTOMY */
'527 ' = '1' /* RAD PANCREATICODUODENECT */
OTHER  = '0' ;

 /* Include Only: Pancreatic Cancer */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRPANCD
'1520 ' = '1'  /* MALIGNANT NEOPL DUODENUM */
'1561 ' = '1'  /* MAL NEO EXTRAHEPAT DUCTS */
'1562 ' = '1'  /* MAL NEO AMPULLA OF VATER */
'1570 ' = '1'  /* MAL NEO PANCREAS HEAD */
'1571 ' = '1'  /* MAL NEO PANCREAS BODY */
'1572 ' = '1'  /* MAL NEO PANCREAS TAIL */
'1573 ' = '1'  /* MAL NEO PANCREATIC DUCT */
'1574 ' = '1'  /* MAL NEO ISLET LANGERHANS */
'1578 ' = '1'  /* MALIG NEO PANCREAS NEC */
'1579 ' = '1'  /*-MALIG NEO PANCREAS NOS-*/
OTHER  = '0' ;

 /* ----------------------------------------- */
 /* Pediatric Heart Surgery (PRPEDH)          */
 /*   Volume Indicator / IQI #3               */
 /*   Mortality (post-op) Indicator / IQI #10 */
 /* ----------------------------------------- */

 /* Pediatric Heart Surgery (#1) */
 /* Procedures to repair congenital heart defect */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRPED1P
'3500' = '1'  /* CLOSED VALVOTOMY NOS */
'3501' = '1'  /* CLOSED AORTIC VALVOTOMY */
'3502' = '1'  /* CLOSED MITRAL VALVOTOMY */
'3503' = '1'  /* CLOSED PULMON VALVOTOMY */
'3504' = '1'  /* CLOSED TRICUSP VALVOTOMY */
'3510' = '1'  /* OPEN VALVULOPLASTY NOS */
'3511' = '1'  /* OPN AORTIC VALVULOPLASTY */
'3512' = '1'  /* OPN MITRAL VALVULOPLASTY */
'3513' = '1'  /* OPN PULMON VALVULOPLASTY */
'3514' = '1'  /* OPN TRICUS VALVULOPLASTY */
'3520' = '1'  /* REPLACE HEART VALVE NOS */
'3521' = '1'  /* REPLACE AORT VALV-TISSUE */
'3522' = '1'  /* REPLACE AORTIC VALVE NEC */
'3523' = '1'  /* REPLACE MITR VALV-TISSUE */
'3524' = '1'  /* REPLACE MITRAL VALVE NEC */
'3525' = '1'  /* REPLACE PULM VALV-TISSUE */
'3526' = '1'  /* REPLACE PULMON VALVE NEC */
'3527' = '1'  /* REPLACE TRIC VALV-TISSUE */
'3528' = '1'  /* REPLACE TRICUSP VALV NEC */
'3531' = '1'  /* PAPILLARY MUSCLE OPS */
'3532' = '1'  /* CHORDAE TENDINEAE OPS */
'3533' = '1'  /* ANNULOPLASTY */
'3534' = '1'  /* INFUNDIBULECTOMY */
'3535' = '1'  /* TRABECUL CARNEAE CORD OP */
'3539' = '1'  /* TISS ADJ TO VALV OPS NEC */
'3541' = '1'  /* ENLARGE EXISTING SEP DEF */
'3542' = '1'  /* CREATE SEPTAL DEFECT */
'3550' = '1'  /* PROSTH REP HRT SEPTA NOS */
'3551' = '1'  /* PROS REP ATRIAL DEF-OPN */
'3552' = '1'  /* PROS REPAIR ATRIA DEF-CL */
'3553' = '1'  /* PROST REPAIR VENTRIC DEF */
'3554' = '1'  /* PROS REP ENDOCAR CUSHION */
'3560' = '1'  /* GRFT REPAIR HRT SEPT NOS */
'3561' = '1'  /* GRAFT REPAIR ATRIAL DEF */
'3562' = '1'  /* GRAFT REPAIR VENTRIC DEF */
'3563' = '1'  /* GRFT REP ENDOCAR CUSHION */
'3570' = '1'  /* HEART SEPTA REPAIR NOS */
'3571' = '1'  /* ATRIA SEPTA DEF REP NEC */
'3572' = '1'  /* VENTR SEPTA DEF REP NEC */
'3573' = '1'  /* ENDOCAR CUSHION REP NEC */
'3581' = '1'  /* TOT REPAIR TETRAL FALLOT */
'3582' = '1'  /* TOTAL REPAIR OF TAPVC */
'3583' = '1'  /* TOT REP TRUNCUS ARTERIOS */
'3584' = '1'  /* TOT COR TRANSPOS GRT VES  */
'3591' = '1'  /* INTERAT VEN RETRN TRANSP */
'3592' = '1'  /* CONDUIT RT VENT-PUL ART */
'3593' = '1'  /* CONDUIT LEFT VENTR-AORTA */
'3594' = '1'  /* CONDUIT ARTIUM-PULM ART */
'3595' = '1'  /* HEART REPAIR REVISION */
'3598' = '1'  /* OTHER HEART SEPTA OPS */
'3599' = '1'  /* OTHER OP ON HRT VALVES */
'3835' = '1'  /* THOR VESSEL RESECT/ANAST */
'3845' = '1'  /* RESECT THORAC VES W REPL */
'3885' = '1'  /* OCCLUDE THORACIC VES NEC */
'390 ' = '1'  /* SYSTEMIC-PULM ART SHUNT */
'3921' = '1'  /* CAVAL-PULMON ART ANASTOM */
'3959' = '1'  /* REPAIR OF VESSEL NEC */
OTHER  = '0' ;

 /* Pediatric Heart Surgery (#2): */
 /* Any other cardiac surgery */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRPED2P
'0050' = '1'  /* IMPL CRT PACEMAKER SYS */
'0051' = '1'  /* IMPL CRT DEFIBRILLAT SYS */
'0052' = '1'  /* IMP/REP LEAD LF VEN SYS */
'0053' = '1'  /* IMP/REP CRT PACEMAKR GEN */
'0054' = '1'  /* IMP/REP CRT DEFIB GENAT */
'3601' = '1'  /* PTCA-1 VES/ATH W/O AGENT */
'3602' = '1'  /* PTCA-1 VES/ATH W AGENT */
'3603' = '1'  /* OPEN CORONRY ANGIOPLASTY */
'3604' = '1'  /* INTRCORONRY THROMB INFUS */
'3605' = '1'  /* PTCA-MULTIPLE VESSEL/ATH */
'3606' = '1'  /* INSERT OF COR ART STENT */
'3607' = '1'  /* INS DRUG-ELUT CORONRY ST */
'3609' = '1'  /* REM OF COR ART OBSTR NEC */
'3610' = '1'  /* AORTOCORONARY BYPASS NOS */
'3611' = '1'  /* AORTOCOR BYPAS-1 COR ART */
'3612' = '1'  /* AORTOCOR BYPAS-2 COR ART */
'3613' = '1'  /* AORTOCOR BYPAS-3 COR ART */
'3614' = '1'  /* AORTCOR BYPAS-4+ COR ART */
'3615' = '1'  /* 1 INT MAM-COR ART BYPASS */
'3616' = '1'  /* 2 INT MAM-COR ART BYPASS */
'3617' = '1'  /* ABD-CORON ARTERY BYPASS */
'3619' = '1'  /* HRT REVAS BYPS ANAS NEC */
'362 ' = '1'  /* ARTERIAL IMPLANT REVASC */
'363 ' = '1'  /* OTH HEART REVASCULAR */
'3631' = '1'  /* OPEN CHEST TRANS REVASC */
'3632' = '1'  /* OTH TRANSMYO REVASCULAR */
'3639' = '1'  /* OTH HEART REVASCULAR */
'3691' = '1'  /* CORON VESS ANEURYSM REP */
'3699' = '1'  /* HEART VESSEL OP NEC */
'370 ' = '1'  /* PERICARDIOCENTESIS */
'3710' = '1'  /* INCISION OF HEART NOS */
'3711' = '1'  /* CARDIOTOMY */
'3712' = '1'  /* PERICARDIOTOMY */
'3721' = '1'  /* RT HEART CARDIAC CATH */
'3722' = '1'  /* LEFT HEART CARDIAC CATH */
'3723' = '1'  /* RT/LEFT HEART CARD CATH */
'3724' = '1'  /* PERICARDIAL BIOPSY */
'3725' = '1'  /* CARDIAC BIOPSY */
'3726' = '1'  /* CARDIAC ELECTROPHY STIM */
'3727' = '1'  /* CARDIAC MAPPING */
'3728' = '1'  /* INTRACARDIAC ECHOCARDIO */
'3729' = '1'  /* HRT/PERICAR DX PROC NEC */
'3731' = '1'  /* PERICARDIECTOMY */
'3732' = '1'  /* HEART ANEURYSM EXCISION */
'3733' = '1'  /* EXC/DEST OTH HRT LESION */
'3734' = '1'  /* CATH ABLATION LES HEART */
'3735' = '1'  /* PARTIAL VENTRICULECTOMY */
'374 ' = '1'  /* HEART & PERICARD REPAIR */
'375 ' = '1'  /* HEART TRANSPLANTATION */
'3761' = '1'  /* PULSATION BALLOON IMPLAN */
'3762' = '1'  /* IMPLANT HRT ASST SYS NEC */
'3763' = '1'  /* REPLACE HRT ASSIST SYST */
'3764' = '1'  /* REMOVE HEART ASSIST SYS */
'3765' = '1'  /* IMP EXT PUL HRT ASST SYS */
'3766' = '1'  /* IMP IMP PUL HRT ASST SYS */
'3767' = '1'  /* IMP CARDIOMYOSTIMUL SYS */
'3770' = '1'  /* INT INSERT PACEMAK LEAD */
'3771' = '1'  /* INT INSERT LEAD IN VENT */
'3772' = '1'  /* INT INSER LEAD ATRI-VENT */
'3773' = '1'  /* INT INSER LEAD IN ATRIUM */
'3774' = '1'  /* INT OR REPL LEAD EPICAR */
'3775' = '1'  /* REVISION OF LEAD */
'3776' = '1'  /* REPL TV ATRI-VENT LEAD */
'3777' = '1'  /* REMOVAL OF LEAD W/O REPL */
'3778' = '1'  /* INSER TEMP PACEMAKER SYS */
'3779' = '1'  /* REVIS OR RELOCATE POCKET */
'3780' = '1'  /* INT OR REPL PERM PACEMKR */
'3781' = '1'  /* INT INSERT 1-CHAM, NON */
'3782' = '1'  /* INT INSERT 1-CHAM, RATE */
'3783' = '1'  /* INT INSERT DUAL-CHAM DEV */
'3785' = '1'  /* REPL PACEM W 1-CHAM, NON */
'3786' = '1'  /* REPL PACEM 1-CHAM, RATE */
'3787' = '1'  /* REPL PACEM W DUAL-CHAM */
'3789' = '1'  /* REVISE OR REMOVE PACEMAK */
'3791' = '1'  /* OPN CHEST CARDIAC MASSAG */
'3792' = '1'  /* INJECTION INTO HEART */
'3793' = '1'  /* INJECTION INTO PERICARD */
'3794' = '1'  /* IMPLT/REPL CARDDEFIB TOT */
'3795' = '1'  /* IMPLT CARDIODEFIB LEADS */
'3796' = '1'  /* IMPLT CARDIODEFIB GENATR */
'3797' = '1'  /* REPL CARDIODEFIB LEADS */
'3798' = '1'  /* REPL CARDIODEFIB GENRATR */
'3799' = '1'  /* OTHER HEART/PERICARD OPS */
OTHER  = '0' ;

 /* Include Only: congenital heart defect */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRPED1D
'7467 ' = '1'  /* HYPOPLAS LEFT HEART SYND */
OTHER  = '0' ;

 /* Pediatric Heart Surgery */
 /* Exclusions */

 /* PHS Exclusion #1: */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRPED2D
'7470 ' = '1'  /* PATENT DUCTUS ARTERIOSUS */
OTHER  = '0' ;

VALUE $BLANK
'    ' = '1'  /* BLANK */
OTHER  = '0' ;

 /* ICD-9-CM Procedure Codes: */

VALUE $PRPED3P
'3885' = '1'  /* OCCLUDE THORACIC VES NEC */
OTHER  = '0' ;

 /* PHS Exclusion #2: */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRPED4P
'3541' = '1'  /* ENLARGE EXISTING SEP DEF */
'3551' = '1'  /* PROS REP ATRIAL DEF-OPN */
'3552' = '1'  /* PROS REPAIR ATRIA DEF-CL */
'3553' = '1'  /* PROST REPAIR VENTRIC DEF */
'3571' = '1'  /* ATRIA SEPTA DEF REP NEC */
'3572' = '1'  /* VENTR SEPTA DEF REP NEC */
OTHER  = '0' ;

 /* ICD-9-CM Procedure Codes: */

VALUE $PRPED5P
'3961' = '1'  /* EXTRACORPOREAL CIRCULAT */
OTHER  = '0' ;

 /* PHS Exclusion #3: */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRPED6P
'3721' = '1'  /* RT HEART CARDIAC CATH */
'3722' = '1'  /* LEFT HEART CARDIAC CATH */
'3723' = '1'  /* RT/LEFT HEART CARD CATH */
'8842' = '1'  /* CONTRAST AORTOGRAM */
'8843' = '1'  /* CONTR PULMON ARTERIOGRAM */
OTHER  = '0' ;

 /* PHS Exclusion #4: */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRPED3D
'7450 ' = '1'  /* COMMON TRUNCUS */
'74510' = '1'  /* COMPL TRANSPOS GREAT VES */
'74511' = '1'  /* DOUBLE OUTLET RT VENTRIC */
'74512' = '1'  /* CORRECT TRANSPOS GRT VES */
'74519' = '1'  /* TRANSPOS GREAT VESS NEC */
'7452 ' = '1'  /* TETRALOGY OF FALLOT */
'7453 ' = '1'  /* COMMON VENTRICLE */
'7454 ' = '1'  /* VENTRICULAR SEPT DEFECT */
'7455 ' = '1'  /* SECUNDUM ATRIAL SEPT DEF */
'74560' = '1'  /* ENDOCARD CUSHION DEF NOS */
'74561' = '1'  /* OSTIUM PRIMUM DEFECT */
'74569' = '1'  /* ENDOCARD CUSHION DEF NEC */
'7457 ' = '1'  /* COR BILOCULARE */
'7458 ' = '1'  /* SEPTAL CLOSURE ANOM NEC */
'7459 ' = '1'  /* SEPTAL CLOSURE ANOM NOS */
'74600' = '1'  /* PULMONARY VALVE ANOM NOS */
'74601' = '1'  /* CONG PULMON VALV ATRESIA */
'74602' = '1'  /* CONG PULMON VALVE STENOS */
'74609' = '1'  /* PULMONARY VALVE ANOM NEC */
'7461 ' = '1'  /* CONG TRICUSP ATRES/STEN */
'7462 ' = '1'  /* EBSTEIN'S ANOMALY */
'7463 ' = '1'  /* CONG AORTA VALV STENOSIS */
'7464 ' = '1'  /* CONG AORTA VALV INSUFFIC */
'7465 ' = '1'  /* CONGEN MITRAL STENOSIS */
'7466 ' = '1'  /* CONG MITRAL INSUFFICIENC */
'7467 ' = '1'  /* HYPOPLAS LEFT HEART SYND */
'74681' = '1'  /* CONG SUBAORTIC STENOSIS */
'74682' = '1'  /* COR TRIATRIATUM */
'74683' = '1'  /* INFUNDIB PULMON STENOSIS */
'74684' = '1'  /* OBSTRUCT HEART ANOM NEC */
'74685' = '1'  /* CORONARY ARTERY ANOMALY */
'74686' = '1'  /* CONGENITAL HEART BLOCK */
'74687' = '1'  /* MALPOSITION OF HEART */
'74689' = '1'  /* CONG HEART ANOMALY NEC */
'7469 ' = '1'  /* CONG HEART ANOMALY NOS */
'7470 ' = '1'  /* PATENT DUCTUS ARTERIOSUS */
'74710' = '1'  /* COARCTATION OF AORTA */
'74711' = '1'  /* INTERRUPT OF AORTIC ARCH */
'74720' = '1'  /* CONG ANOM OF AORTA NOS */
'74721' = '1'  /* ANOMALIES OF AORTIC ARCH */
'74722' = '1'  /* AORTIC ATRESIA/STENOSIS */
'74729' = '1'  /* CONG ANOM OF AORTA NEC */
'7473 ' = '1'  /* PULMONARY ARTERY ANOM */
'74740' = '1'  /* GREAT VEIN ANOMALY NOS */
'74741' = '1'  /* TOT ANOM PULM VEN CONNEC */
'74742' = '1'  /* PART ANOM PULM VEN CONN */
'74749' = '1'  /* GREAT VEIN ANOMALY NEC */
'7475 ' = '1'  /* UMBILICAL ARTERY ABSENCE */
'74760' = '1'  /* UNSP PRPHERL VASC ANOMAL */
'74761' = '1'  /* GSTRONTEST VESL ANOMALY */
'74762' = '1'  /* RENAL VESSEL ANOMALY */
'74763' = '1'  /* UPR LIMB VESSEL ANOMALY */
'74764' = '1'  /* LWR LIMB VESSEL ANOMALY */
'74769' = '1'  /* OTH SPCF PRPH VSCL ANOML */
'74781' = '1'  /* CEREBROVASCULAR ANOMALY */
'74782' = '1'  /* SPINAL VESSEL ANOMALY */
'74783' = '1'  /* PERSISTENT FETAL CIRC */
'74789' = '1'  /* CIRCULATORY ANOMALY NEC */
'7479 ' = '1'  /* CIRCULATORY ANOMALY NOS */
OTHER   = '0' ;


 /* ----------------------------------------- */
 /* Abdominal Aortic Aneurysm Repair (PRAAAR) */
 /*   Volume Indicator / IQI #4               */
 /*   Mortality (post-op) Indicator / IQI #11 */
 /* ----------------------------------------- */

 /* AAA Repair */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRAAARP
'3834' = '1'  /* AORTA RESECTION & ANAST */
'3844' = '1'  /* RESECT ABDM AORTA W REPL */
'3864' = '1'  /* EXCISION OF AORTA */
OTHER  = '0' ;

 /* Include Only: AAA */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRAAARD
'4413 ' = '1'  /* RUPT ABD AORTIC ANEURYSM */
'4414 ' = '1'  /* ABDOM AORTIC ANEURYSM */
OTHER  = '0' ;

 /* ----------------------------------------- */
 /* CABG (PRCABG)                             */
 /*   Volume Indicator / IQI #5               */
 /*   Mortality (post-op) Indicator / IQI #12 */
 /*   Utilization (area) / IQI #26            */
 /* ----------------------------------------- */

 /* CABG */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRCABGP
'3610' = '1'   /* AORTOCORONARY BYPASS NOS */
'3611' = '1'   /* AORTOCOR BYPAS-1 COR ART */
'3612' = '1'   /* AORTOCOR BYPAS-2 COR ART */
'3613' = '1'   /* AORTOCOR BYPAS-3 COR ART */
'3614' = '1'   /* AORTCOR BYPAS-4+ COR ART */
'3615' = '1'   /* 1 INT MAM-COR ART BYPASS */
'3616' = '1'   /* 2 INT MAM-COR ART BYPASS */
'3617' = '1'   /* ABD-CORON ART BYPASS */
'3619' = '1'   /* HRT REVAS BYPS ANAS NEC */
OTHER  = '0';

 /* ---------------------------------------- */
 /* PTCA volume (PRPTCA)                     */
 /*   Volume Indicator / IQI #6              */
 /*   Utilization (area) Indicator / IQI #27 */
 /*   Mortality Indicator / IQI #30          */
 /* ---------------------------------------- */

 /* PTCA */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRPTCAP
'3601' = '1'   /* PTCA-1 VESSEL W/O AGENT */
'3602' = '1'   /* PTCA-1 VESSEL WITH AGNT */
'3605' = '1'   /* PTCA-MULTIPLE VESSEL */
'3606' = '1'   /* INSERT OF COR ART STENT */
OTHER  = '0' ;

 /* -------------------------------------- */
 /* Carotid Endarterectomy volume (PRCEAT) */
 /*   Volume Indicator / IQI #7            */
 /*   Mortality Indicator / IQI #31        */
 /* ---------------------------------------*/

 /* Carotid Endarterectomy */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRCEATP
'3812' = '1'   /* HEAD & NECK ENDARTER NEC */
OTHER  = '0' ;


 * -------------------------------------------------------------- ;
 * --- FORMATS - PROVIDER LEVEL MORTALITY INDICATORS ------------ ;
 * -------------------------------------------------------------- ;

 /* ----------------------------------------- */
 /* Mortality after Hip Replacement (MTHIPR)  */
 /*   Mortality (post-op) Indicator / IQI #14 */
 /* ----------------------------------------- */

 /* Hip Replacement */
 /* ICD-9-CM Procedure Codes: */

VALUE $MTHIPRP
'8151' = '1'   /* TOTAL HIP REPLACEMENT */
'8152' = '1'   /* PARTIAL HIP REPLACEMENT */
'8153' = '1'   /* REVISE HIP REPLACEMENT */
OTHER  = '0' ;

 /* Include Only: Osteoarthrosis of Hip */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $MTHIPRD
'71500' = '1'  /* GENL OSTEOARTHROSIS NOS */
'71509' = '1'  /* GENL OSTEOARTHROSIS MULT */
'71510' = '1'  /* LOC PRIM OSTEOART-UNSPEC */
'71515' = '1'  /* LOC PRIM OSTEOART-PELVIS */
'71518' = '1'  /* LOC PRIM OSTEOARTHR NEC */
'71520' = '1'  /* LOC 2ND OSTEOARTH-UNSPEC */
'71525' = '1'  /* LOC 2ND OSTEOARTH-PELVIS */
'71528' = '1'  /* LOC 2ND OSTEOARTHROS NEC */
'71530' = '1'  /* LOC OSTEOARTH NOS-UNSPEC */
'71535' = '1'  /* LOC OSTEOARTH NOS-PELVIS */
'71538' = '1'  /* LOC OSTEOAR NOS-SITE NEC */
'71580' = '1'  /* OSTEOARTHROSIS-MULT SITE */
'71589' = '1'  /* OSTEOARTHROSIS-MULT SITE */
'71590' = '1'  /* OSTEOARTHROS NOS-UNSPEC */
'71595' = '1'  /* OSTEOARTHROS NOS-PELVIS */
'71598' = '1'  /* OSTEOARTHRO NOS-OTH SITE */
'71650' = '1'  /* POLYARTHRITIS NOS-UNSPEC */
'71655' = '1'  /* POLYARTHRITIS NOS-PELVIS */
'71658' = '1'  /* POLYARTHRIT NOS-OTH SITE */
'71659' = '1'  /* POLYARTHRITIS NOS-MULT */
'71660' = '1'  /* MONOARTHRITIS NOS-UNSPEC */
'71665' = '1'  /* MONOARTHRITIS NOS-PELVIS */
'71668' = '1'  /* MONOARTHRIT NOS-OTH SITE */
'71690' = '1'  /* ARTHROPATHY NOS-UNSPEC */
'71695' = '1'  /* ARTHROPATHY NOS-PELVIS */
'71698' = '1'  /* ARTHROPATHY NOS-OTH SITE */
'71699' = '1'  /* ARTHROPATHY NOS-MULT */
OTHER   = '0' ;

 /* ----------------------------------------------- */
 /* Acute Myocardial Infarction Mortality (MRTAMI)  */
 /*   Mortality Indicator / IQI #15                 */
 /* ----------------------------------------------- */

 /* Acute Myocardial Infarction */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $MRTAMID
'41001' = '1'  /* AMI ANTEROLATERAL, INIT */
'41011' = '1'  /* AMI ANTERIOR WALL, INIT */
'41021' = '1'  /* AMI INFEROLATERAL, INIT */
'41031' = '1'  /* AMI INFEROPOST, INITIAL */
'41041' = '1'  /* AMI INFERIOR WALL, INIT */
'41051' = '1'  /* AMI LATERAL NEC, INITIAL */
'41061' = '1'  /* TRUE POST INFARCT, INIT */
'41071' = '1'  /* SUBENDO INFARCT, INITIAL */
'41081' = '1'  /* AMI NEC, INITIAL */
'41091' = '1'  /* AMI NOS, INITIAL */
OTHER   = '0' ;

 /* -------------------------------------- */
 /* Congestive Heart Failure rate (MRTCHF) */
 /*   Mortality Indicator / IQI #16        */
 /* -------------------------------------- */

 /* CHF */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $MRTCHFD
'39891' = '1'  /* RHEUMATIC HEART FAILURE */
'40201' = '1'  /* MAL HYPERT HRT DIS W CHF */
'40211' = '1'  /* BENIGN HYP HRT DIS W CHF */
'40291' = '1'  /* HYPERTEN HEART DIS W CHF */
'40401' = '1'  /* MAL HYPER HRT/REN W CHF */
'40403' = '1'  /* MAL HYP HRT/REN W CHF&RF */
'40411' = '1'  /* BEN HYPER HRT/REN W CHF */
'40413' = '1'  /* BEN HYP HRT/REN W CHF&RF */
'40491' = '1'  /* HYPER HRT/REN NOS W CHF */
'40493' = '1'  /* HYP HT/REN NOS W CHF&RF */
'4280 ' = '1'  /* CONGESTIVE HEART FAILURE */
'4281 ' = '1'  /* LEFT HEART FAILURE */
'42820' = '1'  /* SYSTOLIC HRT FAILURE NOS */
'42821' = '1'  /* AC SYSTOLIC HRT FAILURE */
'42822' = '1'  /* CHR SYSTOLIC HRT FAILURE */
'42823' = '1'  /* AC ON CHR SYST HRT FAIL */
'42830' = '1'  /* DIASTOLC HRT FAILURE NOS */
'42831' = '1'  /* AC DIASTOLIC HRT FAILURE */
'42832' = '1'  /* CHR DIASTOLIC HRT FAIL */
'42833' = '1'  /* AC ON CHR DIAST HRT FAIL */
'42840' = '1'  /* SYST/DIAST HRT FAIL NOS */
'42841' = '1'  /* AC SYST/DIASTOL HRT FAIL */
'42842' = '1'  /* CHR SYST/DIASTL HRT FAIL */
'42843' = '1'  /* AC/CHR SYST/DIA HRT FAIL */
'4289 ' = '1'  /* HEART FAILURE NOS */
OTHER   = '0' ;

 /* ------------------------------- */
 /* Stroke Mortality (MRTCVD)       */
 /*   Mortality Indicator / IQI #17 */
 /* ------------------------------- */

 /* Stroke */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $MRTCVDD
'430  ' = '1'  /* SUBARACHNOID HEMORRHAGE */
'431  ' = '1'  /* INTRACEREBRAL HEMORRHAGE */
'4320 ' = '1'  /* NONTRAUM EXTRADURAL HEM */
'4321 ' = '1'  /* SUBDURAL HEMORRHAGE */
'4329 ' = '1'  /* INTRACRANIAL HEMORR NOS */
'43301' = '1'  /* BASI ART OCCL W/ INFARCT */
'43311' = '1'  /* CAROTD OCCL W/ INFRCT */
'43321' = '1'  /* VERTB ART OCCL W/ INFRCT */
'43331' = '1'  /* MULT PRECER OCCL W/ INFRCT */
'43381' = '1'  /* PRECER OCCL NEC W/ INFRCT */
'43391' = '1'  /* PRECER OCCL NOS W/ INFRCT */
'43401' = '1'  /* CERE THROMBOSIS W/ INFRCT */
'43411' = '1'  /* CERE EMBOLISM W/ INFRCT */
'43491' = '1'  /* CEREB OCCL NOS W/ INFRCT */
'436  ' = '1'  /* CVA */
OTHER   = '0' ;

 /* ---------------------------------------------- */
 /* Gastrointestinal Hemorrhage mortality (MRTGIH) */
 /*   Mortality Indicator / IQI #18                */
 /* ---------------------------------------------- */

 /* Gastrointestinal Hemorrhage */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $MRTGIHD
'4560 ' = '1'  /* ESOPHAG VARICES W BLEED */
'5307 ' = '1'  /* MALLORY-WEISS SYNDROME */
'53082' = '1'  /* ESOPHAGEAL HEMORRHAGE */
'53100' = '1'  /* AC STOMACH ULCER W HEM */
'53101' = '1'  /* AC STOMAC ULC W HEM-OBST */
'53120' = '1'  /* AC STOMAC ULC W HEM/PERF */
'53121' = '1'  /* AC STOM ULC HEM/PERF-OBS */
'53140' = '1'  /* CHR STOMACH ULC W HEM */
'53141' = '1'  /* CHR STOM ULC W HEM-OBSTR */
'53160' = '1'  /* CHR STOMACH ULC HEM/PERF */
'53161' = '1'  /* CHR STOM ULC HEM/PERF-OB */
'53200' = '1'  /* AC DUODENAL ULCER W HEM */
'53201' = '1'  /* AC DUODEN ULC W HEM-OBST */
'53220' = '1'  /* AC DUODEN ULC W HEM/PERF */
'53221' = '1'  /* AC DUOD ULC HEM/PERF-OBS */
'53240' = '1'  /* CHR DUODEN ULCER W HEM */
'53241' = '1'  /* CHR DUODEN ULC HEM-OBSTR */
'53260' = '1'  /* CHR DUODEN ULC HEM/PERF */
'53261' = '1'  /* CHR DUOD ULC HEM/PERF-OB */
'53300' = '1'  /* AC PEPTIC ULCER W HEMORR */
'53301' = '1'  /* AC PEPTIC ULC W HEM-OBST */
'53320' = '1'  /* AC PEPTIC ULC W HEM/PERF */
'53321' = '1'  /* AC PEPT ULC HEM/PERF-OBS */
'53340' = '1'  /* CHR PEPTIC ULCER W HEM */
'53341' = '1'  /* CHR PEPTIC ULC W HEM-OBS */
'53360' = '1'  /* CHR PEPT ULC W HEM/PERF */
'53361' = '1'  /* CHR PEPT ULC HEM/PERF-OB */
'53400' = '1'  /* AC MARGINAL ULCER W HEM */
'53401' = '1'  /* AC MARGIN ULC W HEM-OBST */
'53420' = '1'  /* AC MARGIN ULC W HEM/PERF */
'53421' = '1'  /* AC MARG ULC HEM/PERF-OBS */
'53440' = '1'  /* CHR MARGINAL ULCER W HEM */
'53441' = '1'  /* CHR MARGIN ULC W HEM-OBS */
'53460' = '1'  /* CHR MARGIN ULC HEM/PERF */
'53461' = '1'  /* CHR MARG ULC HEM/PERF-OB */
'53501' = '1'  /* ACUTE GASTRITIS W HMRHG */
'53511' = '1'  /* ATRPH GASTRITIS W HMRHG */
'53521' = '1'  /* GSTR MCSL HYPRT W HMRG */
'53531' = '1'  /* ALCHL GSTRITIS W HMRHG */
'53541' = '1'  /* OTH SPF GASTRT W HMRHG */
'53551' = '1'  /* GSTR/DDNTS NOS W HMRHG */
'53561' = '1'  /* DUODENITIS W HMRHG */
'53783' = '1'  /* ANGIO STM/DUDN W HMRHG */
'53784' = '1'  /* DIEULAFOY LES,STOM&DUOD */
'56202' = '1'  /* DVRTCLO SML INT W HMRHG */
'56203' = '1'  /* DVRTCLI SML INT W HMRHG */
'56212' = '1'  /* DVRTCLO COLON W HMRHG */
'56213' = '1'  /* DVRTCLI COLON W HMRHG */
'5693 ' = '1'  /* RECTAL & ANAL HEMORRHAGE */
'56985' = '1'  /* ANGIO INTES W HMRHG */
'56986' = '1'  /* DIEULAFOY LES, INTESTINE */
'5780 ' = '1'  /* HEMATEMESIS */
'5781 ' = '1'  /* BLOOD IN STOOL */
'5789 ' = '1'  /* GASTROINTEST HEMORR NOS */
OTHER   = '0' ;

 /* ------------------------------- */
 /* Hip Fracture Mortality (MTHIPF) */
 /*   Mortality Indicator / IQI #19 */
 /* ------------------------------- */

 /* Hip Fracture */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $MTHIPFD
'82000' = '1'  /* FX FEMUR INTRCAPS NOS-CL */
'82001' = '1'  /* FX UP FEMUR EPIPHY-CLOS */
'82002' = '1'  /* FX FEMUR, MIDCERVIC-CLOS */
'82003' = '1'  /* FX BASE FEMORAL NCK-CLOS */
'82009' = '1'  /* FX FEMUR INTRCAPS NEC-CL */
'82010' = '1'  /* FX FEMUR INTRCAP NOS-OPN */
'82011' = '1'  /* FX UP FEMUR EPIPHY-OPEN */
'82012' = '1'  /* FX FEMUR, MIDCERVIC-OPEN */
'82013' = '1'  /* FX BASE FEMORAL NCK-OPEN */
'82019' = '1'  /* FX FEMUR INTRCAP NEC-OPN */
'82020' = '1'  /* TROCHANTERIC FX NOS-CLOS */
'82021' = '1'  /* INTERTROCHANTERIC FX-CL */
'82022' = '1'  /* SUBTROCHANTERIC FX-CLOSE */
'82030' = '1'  /* TROCHANTERIC FX NOS-OPEN */
'82031' = '1'  /* INTERTROCHANTERIC FX-OPN */
'82032' = '1'  /* SUBTROCHANTERIC FX-OPEN */
'8208 ' = '1'  /* FX NECK OF FEMUR NOS-CL */
'8209 ' = '1'  /* FX NECK OF FEMUR NOS-OPN */
OTHER   = '0' ;

 /* ------------------------------- */
 /* Pneumonia mortality (MTPNEU)    */
 /*   Mortality Indicator / IQI #20 */
 /* ------------------------------- */

 /* Pneumonia */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $MTPNEUD
'00322' = '1'  /* SALMONELLA PNEUMONIA */
'0212 ' = '1'  /* PULMONARY TULAREMIA */
'0391 ' = '1'  /* PULMONARY ACTINOMYCOSIS */
'0521 ' = '1'  /* VARICELLA PNEUMONITIS */
'0551 ' = '1'  /* POSTMEASLES PNEUMONIA */
'0730 ' = '1'  /* ORNITHOSIS PNEUMONIA */
'1124 ' = '1'  /* CANDIDIASIS OF LUNG */
'1140 ' = '1'  /* PRIMARY COCCIDIOIDOMYCOS */
'1144 ' = '1'  /* CHRONIC PULMON COCCIDIOIDOMYCOSIS  */
'1145 ' = '1'  /* UNSPEC PULMON COCCIDIOIDOMYCOSIS  */
'11505' = '1'  /* HISTOPLASM CAPS PNEUMON */
'11515' = '1'  /* HISTOPLASM DUB PNEUMONIA  */
'11595' = '1'  /* HISTOPLASMOSIS PNEUMONIA */
'1304 ' = '1'  /* TOXOPLASMA PNEUMONITIS */
'1363 ' = '1'  /* PNEUMOCYSTOSIS */
'4800 ' = '1'  /* ADENOVIRAL PNEUMONIA */
'4801 ' = '1'  /* RESP SYNCYT VIRAL PNEUM */
'4802 ' = '1'  /* PARINFLUENZA VIRAL PNEUM */
'4808 ' = '1'  /* VIRAL PNEUMONIA NEC */
'4809 ' = '1'  /* VIRAL PNEUMONIA NOS */
'481  ' = '1'  /* PNEUMOCOCCAL PNEUMONIA */
'4820 ' = '1'  /* K. PNEUMONIAE PNEUMONIA */
'4821 ' = '1'  /* PSEUDOMONAL PNEUMONIA */
'4822 ' = '1'  /* H.INFLUENZAE PNEUMONIA */
'48230' = '1'  /* STREP PNEUMONIA UNSPEC */
'48231' = '1'  /* GRP A STREP PNEUMONIA */
'48232' = '1'  /* GRP B STREP PNEUMONIA */
'48239' = '1'  /* OTH STREP PNEUMONIA */
'4824 ' = '1'  /* STAPHYLOCOCCAL PNEUMONIA */
'48240' = '1'  /* STAPH PNEUMONIA UNSP */
'48241' = '1'  /* STAPH AUREUS PNEUMON */
'48249' = '1'  /* STAPH PNEUMON OTH */
'48281' = '1'  /* ANAEROBIC PNEUMONIA */
'48282' = '1'  /* E COLI PNEUMONIA */
'48283' = '1'  /* OTH GRAM NEG PNEUMONIA */
'48284' = '1'  /* LEGIONNAIRES DX */
'48289' = '1'  /* BACT PNEUMONIA NEC */
'4829 ' = '1'  /* BACTERIAL PNEUMONIA NOS */
'4830 ' = '1'  /* MYCOPLASMA PNEUMONIA */
'4831 ' = '1'  /* CHLAMYDIA PNEUMONIA */
'4838 ' = '1'  /* OTH SPEC ORG PNEUMONIA */
'4841 ' = '1'  /* PNEUM W CYTOMEG INCL DIS */
'4843 ' = '1'  /* PNEUMONIA IN WHOOP COUGH */
'4845 ' = '1'  /* PNEUMONIA IN ANTHRAX */
'4846 ' = '1'  /* PNEUM IN ASPERGILLOSIS */
'4847 ' = '1'  /* PNEUM IN OTH SYS MYCOSES */
'4848 ' = '1'  /* PNEUM IN INFECT DIS NEC */
'485  ' = '1'  /* BRONCOPNEUMONIA ORG NOS */
'486  ' = '1'  /* PNEUMONIA, ORGANISM NOS */
'5070 ' = '1'  /* FOOD/VOMIT PNEUMONITIS */
'5100 ' = '1'  /* EMPYEMA WITH FISTULA */
'5109 ' = '1'  /* EMPYEMA W/O FISTULA */
'5110 ' = '1'  /* PLEURISY W/O EFFUS OR TB */
'5130 ' = '1'  /* ABSCESS OF LUNG */
OTHER  = '0' ;


 * -------------------------------------------------------------- ;
 * --- FORMATS - PROVIDER LEVEL UTILIZATION INDICATORS ---------- ;
 * -------------------------------------------------------------- ;

 /* -------------------------------------------------- */
 /* Vaginal Birth after Cesarean Section rate (PRVBAC) */
 /*   Utilization (provider) Indicator / IQI #22       */
 /* -------------------------------------------------- */

 /* Previous C-Section (Population at Risk): */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRVBACD
'65420' = '1'  /* PREV C-SECT NOS-UNSPEC */
'65421' = '1'  /* PREV C-SECT NOS-DELIVER */
'65423' = '1'  /* PREV C-SECT NOS-ANTEPART */
OTHER   = '0' ;

 /* -------------------------------------------- */
 /* Laparoscopic Cholecystectomy rate (PRLAPO)   */
 /*   Utilization (provider) Indicator / IQI #23 */
 /* -------------------------------------------- */

 /* Laparoscopic Cholecystectomy (Outcome of Interest): */
 /* ICD-9-CM Procedure Code: */

VALUE $PRLAPOP
'5123' = '1'   /* LAPAROSCOPIC CHOLE */
OTHER  = '0' ;

 /* Cholecystectomy (Population at Risk): */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRLAP2P
'5122' = '1'   /* CHOLECYSTECTOMY */
'5123' = '1'   /* LAPAROSCOPIC CHOLE */
OTHER  = '0' ;

 /* Include Only: Uncomplicated Cholecystitis and/or Cholelithiasis */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRLAPOD
'57400' = '1'  /* CHOLELITH W AC CHOLECYST */
'57401' = '1'  /* CHOLELITH/AC GB INF-OBST */
'57410' = '1'  /* CHOLELITH W CHOLECYS NEC */
'57411' = '1'  /* CHOLELITH/GB INF NEC-OBS */
'57420' = '1'  /* CHOLELITHIASIS NOS */
'57421' = '1'  /* CHOLELITHIAS NOS W OBSTR */
'5750 ' = '1'  /* ACUTE CHOLECYSTITIS */
'5751 ' = '1'  /* CHOLECYSTITIS NEC */
'57510' = '1'  /* CHOLECYSTITIS NOS */
'57511' = '1'  /* CHRON CHOLECYSTITIS */
'57512' = '1'  /* AC/CHR CHOLECYSTITIS */
OTHER   = '0' ;

 /* -------------------------------------------- */
 /* Incidental Appendectomy rate (PRAPPN)        */
 /*   Utilization (provider) Indicator / IQI #24 */
 /* -------------------------------------------- */

 /* Incidental Appendectomy (Outcome of Interest): */
 /* ICD-9-CM Procedure Code: */

VALUE $PRAPPNP
'471 ' = '1'   /* INCIDENTAL APPENDECTOMY */
'4711' = '1'   /* LAPAROSCOP INCID APPEND */
'4719' = '1'   /* OTH INCID APPEND */
OTHER  = '0' ;

 /* Intra-Abdominal Procedure (Population at Risk): */
 /* DRGs: */

VALUE PRAPPNG
146 = '1'     /* RECTAL RESECTION W CC */
147 = '1'     /* RECTAL RESECTION W/O CC */
148 = '1'     /* MAJ BOWEL PROC W CC */
149 = '1'     /* MAJ BOWEL PROC W/0 CC */
150 = '1'     /* PERITONEAL ADHES W CC */
151 = '1'     /* PERITONEAL ADHES W/O CC */
152 = '1'     /* MIN BOWEL PROC W CC */
153 = '1'     /* MIN BOWEL PROC W/O CC */
154 = '1'     /* UGI PROC AGE >17 W CC */
155 = '1'     /* UGI PROC AGE >17 W/O CC */
170 = '1'     /* OTH GI OR PROC W CC */
171 = '1'     /* OTH GI OR PROC W/O CC */
191 = '1'     /* PANC LVR SHNT PRC W CC */
192 = '1'     /* PANC LVR SHNT PRC W/O CC */
193 = '1'     /* BILIARY PROC W/ CC */
194 = '1'     /* BILIARY PROC W/O CC */
195 = '1'     /* CHOLE W/ CDE W/ CC */
196 = '1'     /* CHOLE W/ CDE W/O CC */
197 = '1'     /* CHOLE W/ CC */
198 = '1'     /* CHOLE W/O CC */
201 = '1'     /* OTH BILIARY/PANC PROC */
354 = '1'     /* UTER PROC MALIG W/ CC */
355 = '1'     /* UTER PROC MALIG W/O CC */
356 = '1'     /* FEMALE REPROD RECONSTR */
357 = '1'     /* UTER PROC OVARIAN MALIG */
358 = '1'     /* UTER PROC NONMALIG W/ CC */
359 = '1'     /* UTER PROC NONMALI W/O CC */
365 = '1'     /* OTH FEMAL REPROD PROC */
OTHER = '0' ;

 /* -------------------------------------------- */
 /* Bi-lateral Catheterization rate (PRCATH)     */
 /*   Utilization (provider) Indicator / IQI #25 */
 /* -------------------------------------------- */

 /* Bi-lateral Catheterization (Outcome of Interest): */
 /* ICD-9-CM Procedure Code: */

VALUE $PRCATHP
'3723' = '1'  /* RT/LEFT HEART CARD CATH */
OTHER  = '0' ;

 /*  Catheterization (Population at Risk) */
 /* ICD-9-CM Procedure Code: */

VALUE $PRCAT2P
'3722' = '1'  /* LEFT HEART CARDIAC CATH */
'3723' = '1'  /* RT/LEFT HEART CARD CATH */
OTHER  = '0' ;

 /* Include only: Coronary artery disease */
 /* ICD-9-CM Diagnosis Code: */

VALUE $PRCATHD
'41000' = '1'  /* AMI ANTEROLATERAL,UNSPEC */
'41001' = '1'  /* AMI ANTEROLATERAL, INIT */
'41002' = '1'  /* AMI ANTEROLATERAL,SUBSEQ */
'41010' = '1'  /* AMI ANTERIOR WALL,UNSPEC */
'41011' = '1'  /* AMI ANTERIOR WALL, INIT */
'41012' = '1'  /* AMI ANTERIOR WALL,SUBSEQ */
'41020' = '1'  /* AMI INFEROLATERAL,UNSPEC */
'41021' = '1'  /* AMI INFEROLATERAL, INIT */
'41022' = '1'  /* AMI INFEROLATERAL,SUBSEQ */
'41030' = '1'  /* AMI INFEROPOST, UNSPEC */
'41031' = '1'  /* AMI INFEROPOST, INITIAL */
'41032' = '1'  /* AMI INFEROPOST, SUBSEQ */
'41040' = '1'  /* AMI INFERIOR WALL,UNSPEC */
'41041' = '1'  /* AMI INFERIOR WALL, INIT */
'41042' = '1'  /* AMI INFERIOR WALL,SUBSEQ */
'41050' = '1'  /* AMI LATERAL NEC, UNSPEC */
'41051' = '1'  /* AMI LATERAL NEC, INITIAL */
'41052' = '1'  /* AMI LATERAL NEC, SUBSEQ */
'41060' = '1'  /* TRUE POST INFARCT,UNSPEC */
'41061' = '1'  /* TRUE POST INFARCT, INIT */
'41062' = '1'  /* TRUE POST INFARCT,SUBSEQ */
'41070' = '1'  /* SUBENDO INFARCT, UNSPEC */
'41071' = '1'  /* SUBENDO INFARCT, INITIAL */
'41072' = '1'  /* SUBENDO INFARCT, SUBSEQ */
'41080' = '1'  /* AMI NEC, UNSPECIFIED */
'41081' = '1'  /* AMI NEC, INITIAL */
'41082' = '1'  /* AMI NEC, SUBSEQUENT */
'41090' = '1'  /* AMI NOS, UNSPECIFIED */
'41091' = '1'  /* AMI NOS, INITIAL */
'41092' = '1'  /* AMI NOS, SUBSEQUENT */
'4110 ' = '1'  /* POST MI SYNDROME */
'4111 ' = '1'  /* INTERMED CORONARY SYND */
'41181' = '1'  /* CORONARY OCCLSN W/O MI */
'41189' = '1'  /* AC ISCHEMIC HRT DIS NEC */
'412  ' = '1'  /* OLD MYOCARDIAL INFARCT */
'4130 ' = '1'  /* ANGINA DECUBITUS */
'4131 ' = '1'  /* PRINZMETAL ANGINA */
'4139 ' = '1'  /* ANGINA PECTORIS NEC/NOS */
'4140 ' = '1'  /* CORONARY ATHEROSCLEROSIS */
'41400' = '1'  /* COR ATH UNSP VSL NTV/GFT */
'41401' = '1'  /* CRNRY ATHRSCL NATVE VSSL */
'41402' = '1'  /* CRN ATH ATLG VN BPS GRFT */
'41403' = '1'  /* CRN ATH NONATLG BLG GRFT */
'41404' = '1'  /* COR ATH ARTRY BYPAS GRFT */
'41405' = '1'  /* COR ATH BYPASS GRAFT NOS */
'41406' = '1'  /* ATH COR ARTRY TRANSP HRT */
'41410' = '1'  /* ANEURYSM, HEART (WALL) */
'41411' = '1'  /* CORONARY VESSEL ANEURYSM */
'41412' = '1'  /* DISSECTION COR ARTERY */
'41419' = '1'  /* ANEURYSM OF HEART NEC */
'4148 ' = '1'  /* CHR ISCHEMIC HRT DIS NEC */
'4149 ' = '1'  /* CHR ISCHEMIC HRT DIS NOS */
OTHER  = '0' ;

 /* Exclude: Indications for righ cath */
 /* ICD-9-CM Diagnosis Code: */

VALUE $PRCAT2D
'3910 ' = '1'  /* ACUTE RHEUMATIC PERICARD */
'3911 ' = '1'  /* ACUTE RHEUMATIC ENDOCARD */
'3912 ' = '1'  /* AC RHEUMATIC MYOCARDITIS */
'3918 ' = '1'  /* AC RHEUMAT HRT DIS NEC */
'3919 ' = '1'  /* AC RHEUMAT HRT DIS NOS */
'3920 ' = '1'  /* RHEUM CHOREA W HRT INVOL */
'3929 ' = '1'  /* RHEUMATIC CHOREA NOS */
'393  ' = '1'  /* CHR RHEUMATIC PERICARD */
'3940 ' = '1'  /* MITRAL STENOSIS */
'3941 ' = '1'  /* RHEUMATIC MITRAL INSUFF */
'3942 ' = '1'  /* MITRAL STENOSIS W INSUFF */
'3949 ' = '1'  /* MITRAL VALVE DIS NEC/NOS */
'3960 ' = '1'  /* MITRAL/AORTIC STENOSIS */
'3961 ' = '1'  /* MITRAL STENOS/AORT INSUF */
'3962 ' = '1'  /* MITRAL INSUF/AORT STENOS */
'3963 ' = '1'  /* MITRAL/AORTIC VAL INSUFF */
'3968 ' = '1'  /* MITR/AORTIC MULT INVOLV */
'3969 ' = '1'  /* MITRAL/AORTIC V DIS NOS */
'3970 ' = '1'  /* TRICUSPID VALVE DISEASE */
'3971 ' = '1'  /* RHEUM PULMON VALVE DIS */
'3979 ' = '1'  /* RHEUM ENDOCARDITIS NOS */
'3980 ' = '1'  /* RHEUMATIC MYOCARDITIS */
'39890' = '1'  /* RHEUMATIC HEART DIS NOS */
'39891' = '1'  /* RHEUMATIC HEART FAILURE */
'39899' = '1'  /* RHEUMATIC HEART DIS NEC */
'40200' = '1'  /* MAL HYPERTEN HRT DIS NOS */
'40201' = '1'  /* MAL HYPERT HRT DIS W CHF */
'40210' = '1'  /* BEN HYPERTEN HRT DIS NOS */
'40211' = '1'  /* BENIGN HYP HRT DIS W CHF */
'40290' = '1'  /* HYPERTENSIVE HRT DIS NOS */
'40291' = '1'  /* HYPERTEN HEART DIS W CHF */
'40400' = '1'  /* MAL HY HT/REN W/O HF/RF */
'40401' = '1'  /* MAL HYPER HRT/REN W HF */
'40402' = '1'  /* MAL HY HT/REN W REN FAIL */
'40403' = '1'  /* MAL HYP HRT/REN W HF/RF */
'40410' = '1'  /* BEN HY HT/REN W/O HF/RF */
'40411' = '1'  /* BEN HYPER HRT/REN W HF */
'40412' = '1'  /* BEN HY HT/REN W REN FAIL */
'40413' = '1'  /* BEN HYP HRT/REN W HF/RF */
'40490' = '1'  /* HY HT/REN NOS W/O HF/RF */
'40491' = '1'  /* HYPER HRT/REN NOS W HF */
'40492' = '1'  /* HY HT/REN NOS W REN FAIL */
'40493' = '1'  /* HYP HRT/REN NOS W HF/RF */
'4150 ' = '1'  /* ACUTE COR PULMONALE */
'4151 ' = '1'  /* PULMON EMBOLISM/INFARCT */
'41511' = '1'  /* IATROGEN PULM EMB/INFARC */
'41519' = '1'  /* PULM EMBOL/INFARCT NEC */
'4160 ' = '1'  /* PRIM PULM HYPERTENSION */
'4161 ' = '1'  /* KYPHOSCOLIOTIC HEART DIS */
'4168 ' = '1'  /* CHR PULMON HEART DIS NEC */
'4169 ' = '1'  /* CHR PULMON HEART DIS NOS */
'4170 ' = '1'  /* ARTERIOVEN FISTU PUL VES */
'4171 ' = '1'  /* PULMON ARTERY ANEURYSM */
'4178 ' = '1'  /* PULMON CIRCULAT DIS NEC */
'4179 ' = '1'  /* PULMON CIRCULAT DIS NOS */
'4242 ' = '1'  /* NONRHEUM TRICUSP VAL DIS */
'4243 ' = '1'  /* PULMONARY VALVE DISORDER */
'7450 ' = '1'  /* COMMON TRUNCUS */
'74510' = '1'  /* COMPL TRANSPOS GREAT VES */
'74511' = '1'  /* DOUBLE OUTLET RT VENTRIC */
'74512' = '1'  /* CORRECT TRANSPOS GRT VES */
'74519' = '1'  /* TRANSPOS GREAT VESS NEC */
'7452 ' = '1'  /* TETRALOGY OF FALLOT */
'7453 ' = '1'  /* COMMON VENTRICLE */
'7454 ' = '1'  /* VENTRICULAR SEPT DEFECT */
'7455 ' = '1'  /* SECUNDUM ATRIAL SEPT DEF */
'74560' = '1'  /* ENDOCARD CUSHION DEF NOS */
'74561' = '1'  /* OSTIUM PRIMUM DEFECT */
'74569' = '1'  /* ENDOCARD CUSHION DEF NEC */
'7457 ' = '1'  /* COR BILOCULARE */
'7458 ' = '1'  /* SEPTAL CLOSURE ANOM NEC */
'7459 ' = '1'  /* SEPTAL CLOSURE ANOM NOS */
'74600' = '1'  /* PULMONARY VALVE ANOM NOS */
'74601' = '1'  /* CONG PULMON VALV ATRESIA */
'74602' = '1'  /* CONG PULMON VALVE STENOS */
'74609' = '1'  /* PULMONARY VALVE ANOM NEC */
'7461 ' = '1'  /* CONG TRICUSP ATRES/STEN */
'7462 ' = '1'  /* EBSTEIN'S ANOMALY */
'7463 ' = '1'  /* CONG AORTA VALV STENOSIS */
'7464 ' = '1'  /* CONG AORTA VALV INSUFFIC */
'7465 ' = '1'  /* CONGEN MITRAL STENOSIS */
'7466 ' = '1'  /* CONG MITRAL INSUFFICIENC */
'7467 ' = '1'  /* HYPOPLAS LEFT HEART SYND */
'74681' = '1'  /* CONG SUBAORTIC STENOSIS */
'74682' = '1'  /* COR TRIATRIATUM */
'74683' = '1'  /* INFUNDIB PULMON STENOSIS */
'74684' = '1'  /* OBSTRUCT HEART ANOM NEC */
'74685' = '1'  /* CORONARY ARTERY ANOMALY */
'74686' = '1'  /* CONGENITAL HEART BLOCK */
'74687' = '1'  /* MALPOSITION OF HEART */
'74689' = '1'  /* CONG HEART ANOMALY NEC */
'7469 ' = '1'  /* CONG HEART ANOMALY NOS */
'7470 ' = '1'  /* PATENT DUCTUS ARTERIOSUS */
'74710' = '1'  /* COARCTATION OF AORTA */
'74711' = '1'  /* INTERRUPT OF AORTIC ARCH */
'74720' = '1'  /* CONG ANOM OF AORTA NOS */
'74721' = '1'  /* ANOMALIES OF AORTIC ARCH */
'74722' = '1'  /* AORTIC ATRESIA/STENOSIS */
'74729' = '1'  /* CONG ANOM OF AORTA NEC */
'7473 ' = '1'  /* PULMONARY ARTERY ANOM */
'74740' = '1'  /* GREAT VEIN ANOMALY NOS */
'74741' = '1'  /* TOT ANOM PULM VEN CONNEC */
'74742' = '1'  /* PART ANOM PULM VEN CONN */
'74749' = '1'  /* GREAT VEIN ANOMALY NEC */
'7475 ' = '1'  /* UMBILICAL ARTERY ABSENCE */
'74760' = '1'  /* UNSP PRPHERL VASC ANOMAL */
'74761' = '1'  /* GSTRONTEST VESL ANOMALY */
'74762' = '1'  /* RENAL VESSEL ANOMALY */
'74763' = '1'  /* UPR LIMB VESSEL ANOMALY */
'74764' = '1'  /* LWR LIMB VESSEL ANOMALY */
'74769' = '1'  /* OTH SPCF PRPH VSCL ANOML */
'74781' = '1'  /* CEREBROVASCULAR ANOMALY */
'74782' = '1'  /* SPINAL VESSEL ANOMALY */
'74783' = '1'  /* PERSISTENT FETAL CIRC */
'74789' = '1'  /* CIRCULATORY ANOMALY NEC */
'7479 ' = '1'  /* CIRCULATORY ANOMALY NOS */
OTHER  = '0' ;


 * -------------------------------------------------------------- ;
 * --- FORMATS - AREA LEVEL UTILIZATION INDICATORS -------------- ;
 * -------------------------------------------------------------- ;

 /* ---------------------------------------- */
 /* Hysterectomy rate (PRHYST)               */
 /*   Utilization (area) Indicator / IQI #28 */
 /* ---------------------------------------- */

 /* Hysterectomy */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRHYSTP
'683 ' = '1'   /* SUBTOT ABD HYSTERECTOMY */
'684 ' = '1'   /* TOTAL ABD HYSTERECTOMY */
'685 ' = '1'   /* VAGINAL HYSTERECTOMY */
'6851' = '1'   /* LAPAR ASSIST VAG HYS */
'6859' = '1'   /* OTH VAG HYS */
'686 ' = '1'   /* RADICAL ABD HYSTERECTOMY */
'687 ' = '1'   /* RADICAL VAG HYSTERECTOMY */
'689 ' = '1'   /* HYSTERECTOMY NEC/NOS */
OTHER  = '0' ;

 /* Exclude: Female Genital Cancer */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRHYS1D
'179  ' = '1'  /* MALIG NEOPL UTERUS NOS */
'1800 ' = '1'  /* MALIG NEO ENDOCERVIX */
'1801 ' = '1'  /* MALIG NEO EXOCERVIX */
'1808 ' = '1'  /* MALIG NEO CERVIX NEC */
'1809 ' = '1'  /* MAL NEO CERVIX UTERI NOS */
'181  ' = '1'  /* MALIGNANT NEOPL PLACENTA */
'1820 ' = '1'  /* MALIG NEO CORPUS UTERI */
'1821 ' = '1'  /* MAL NEO UTERINE ISTHMUS */
'1828 ' = '1'  /* MAL NEO BODY UTERUS NEC */
'1830 ' = '1'  /* MALIGN NEOPL OVARY */
'1832 ' = '1'  /* MAL NEO FALLOPIAN TUBE */
'1833 ' = '1'  /* MAL NEO BROAD LIGAMENT */
'1834 ' = '1'  /* MALIG NEO PARAMETRIUM */
'1835 ' = '1'  /* MAL NEO ROUND LIGAMENT */
'1838 ' = '1'  /* MAL NEO ADNEXA NEC */
'1839 ' = '1'  /* MAL NEO ADNEXA NOS */
'1840 ' = '1'  /* MALIGN NEOPL VAGINA */
'1841 ' = '1'  /* MAL NEO LABIA MAJORA */
'1842 ' = '1'  /* MAL NEO LABIA MINORA */
'1843 ' = '1'  /* MALIGN NEOPL CLITORIS */
'1844 ' = '1'  /* MALIGN NEOPL VULVA NOS */
'1848 ' = '1'  /* MAL NEO FEMALE GENIT NEC */
'1849 ' = '1'  /* MAL NEO FEMALE GENIT NOS */
'2331 ' = '1'  /* CA IN SITU CERVIX UTERI */
'2332 ' = '1'  /* CA IN SITU UTERUS NEC */
'2333 ' = '1'  /* CA IN SITU FEM GEN NEC */
'2360 ' = '1'  /* UNCERT BEHAV NEO UTERUS */
'2361 ' = '1'  /* UNC BEHAV NEO PLACENTA */
'2362 ' = '1'  /* UNC BEHAV NEO OVARY */
'2363 ' = '1'  /* UNC BEHAV NEO FEMALE NEC */
OTHER   = '0' ;

 /* Exclude: Pelvic or Lower Abdominal Trauma */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRHYS2D
'8674 ' = '1'  /* UTERUS INJURY-CLOSED */
'8675 ' = '1'  /* UTERUS INJURY-OPEN */
'8676 ' = '1'  /* PELVIC ORGAN INJ NEC-CL */
'8677 ' = '1'  /* PELVIC ORGAN INJ NEC-OPN */
'8678 ' = '1'  /* PELVIC ORGAN INJ NOS-CL */
'8679 ' = '1'  /* PELVIC ORGAN INJ NOS-OPN */
'86800' = '1'  /* INTRA-ABDOM INJ NOS-CLOS */
'86803' = '1'  /* PERITONEUM INJURY-CLOSED */
'86804' = '1'  /* RETROPERITONEUM INJ-CL */
'86809' = '1'  /* INTRA-ABDOM INJ NEC-CLOS */
'86810' = '1'  /* INTRA-ABDOM INJ NOS-OPEN */
'86813' = '1'  /* PERITONEUM INJURY-OPEN */
'86814' = '1'  /* RETROPERITONEUM INJ-OPEN */
'86819' = '1'  /* INTRA-ABDOM INJ NEC-OPEN */
'8690 ' = '1'  /* INTERNAL INJ NOS-CLOSED */
'8691 ' = '1'  /* INTERNAL INJURY NOS-OPEN */
'8796 ' = '1'  /* OPEN WOUND OF TRUNK NEC */
'8797 ' = '1'  /* OPEN WND TRUNK NEC-COMPL */
'8798 ' = '1'  /* OPEN WOUND SITE NOS */
'8799 ' = '1'  /* OPN WOUND SITE NOS-COMPL */
'9060 ' = '1'  /* LT EFF OPN WND HEAD/TRNK */
'9081 ' = '1'  /* LATE EFF INT INJ ABDOMEN */
'9082 ' = '1'  /* LATE EFF INT INJURY NEC */
'9391 ' = '1'  /* FOREIGN BODY UTERUS */
'9474 ' = '1'  /* BURN OF VAGINA & UTERUS */
OTHER   = '0' ;

 /* ---------------------------------------------- */
 /* Laminectomy and/or spinal fusion rate (PRLAMI) */
 /*   Utilization (area) Indicator / IQI #29       */
 /* ---------------------------------------------- */

 /* Laminectomy and/or Spinal Fusion */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRLAMIP
'0302' = '1'   /* REOPEN LAMINECTOMY SITE */
'0309' = '1'   /* SPINAL CANAL EXPLOR NEC */
'8050' = '1'   /* EXC/DEST INTVRT DISC NOS */
'8051' = '1'   /* EXCISION INTERVERT DISC */
'8059' = '1'   /* OTH EXC/DEST INTVRT DISC */
'8100' = '1'   /* SPINAL FUSION NOS */
'8101' = '1'   /* ATLAS-AXIS FUSION */
'8102' = '1'   /* OTH CERV FUSION, ANTER */
'8103' = '1'   /* OTH CERV FUSION, POSTER */
'8104' = '1'   /* DORSAL FUSION, ANTERIOR */
'8105' = '1'   /* DORSAL FUSION, POSTERIOR */
'8106' = '1'   /* LUMBAR FUSION, ANTERIOR */
'8107' = '1'   /* LUMBAR FUSION, LATERAL */
'8108' = '1'   /* LUMBAR FUSION, POSTERIOR */
'8109' = '1'   /* REFUSION OF SPINE */
'8130' = '1'   /* SPINAL REFUSION NOS */
'8131' = '1'   /* REFUSION OF ATLAS-AXIS */
'8132' = '1'   /* REFUSION OF OTH CERV ANT */
'8133' = '1'   /* REFUS OF OTH CERV POST */
'8134' = '1'   /* REFUSION OF DORSAL ANT */
'8135' = '1'   /* REFUSION OF DORSAL POST */
'8136' = '1'   /* REFUSION OF LUMBAR ANT */
'8137' = '1'   /* REFUSION OF LUMBAR LAT */
'8138' = '1'   /* REFUSION OF LUMBAR POST */
'8139' = '1'   /* REFUSION OF SPINE NEC */
'8161' = '1'   /* 360 SPINAL FUSION */
'8451' = '1'   /* INS SPINAL FUSION DEVICE */
OTHER  = '0' ;


 * ----------------------------------------------------- ;
 * ---   AREA FORMATS     ------------------------------ ;
 * ---   Translates FIPS State and County Code (SSCCC)   ;
 * ---   to MSA (Metropolitan Statistical Area)          ;
 * ----------------------------------------------------- ;

VALUE AREA
1000  = '01000'
1001  = '5240 '
1003  = '5160 '
1005  = '01005'
1007  = '01007'
1009  = '1000 '
1011  = '01011'
1013  = '01013'
1015  = '0450 '
1017  = '01017'
1019  = '01019'
1021  = '01021'
1023  = '01023'
1025  = '01025'
1027  = '01027'
1029  = '01029'
1031  = '01031'
1033  = '2650 '
1035  = '01035'
1037  = '01037'
1039  = '01039'
1041  = '01041'
1043  = '01043'
1045  = '2180 '
1047  = '01047'
1049  = '01049'
1051  = '5240 '
1053  = '01053'
1055  = '2880 '
1057  = '01057'
1059  = '01059'
1061  = '01061'
1063  = '01063'
1065  = '01065'
1067  = '01067'
1069  = '2180 '
1071  = '01071'
1073  = '1000 '
1075  = '01075'
1077  = '2650 '
1079  = '2030 '
1081  = '0580 '
1083  = '3440 '
1085  = '01085'
1087  = '01087'
1089  = '3440 '
1091  = '01091'
1093  = '01093'
1095  = '01095'
1097  = '5160 '
1099  = '01099'
1101  = '5240 '
1103  = '2030 '
1105  = '01105'
1107  = '01107'
1109  = '01109'
1111  = '01111'
1113  = '1800 '
1115  = '1000 '
1117  = '1000 '
1119  = '01119'
1121  = '01121'
1123  = '01123'
1125  = '8600 '
1127  = '01127'
1129  = '01129'
1131  = '01131'
1133  = '01133'
2000  = '02000'
2013  = '02013'
2016  = '02016'
2020  = '0380 '
2050  = '02050'
2060  = '02060'
2068  = '02068'
2070  = '02070'
2090  = '02090'
2100  = '02100'
2110  = '02110'
2122  = '02122'
2130  = '02130'
2150  = '02150'
2164  = '02164'
2170  = '02170'
2180  = '02180'
2185  = '02185'
2188  = '02188'
2201  = '02201'
2220  = '02220'
2231  = '02231'
2232  = '02232'
2240  = '02240'
2261  = '02261'
2270  = '02270'
2280  = '02280'
2282  = '02282'
2290  = '02290'
4000  = '04000'
4001  = '04001'
4003  = '04003'
4005  = '2620 '
4007  = '04007'
4009  = '04009'
4011  = '04011'
4012  = '04012'
4013  = '6200 '
4015  = '4120 '
4017  = '04017'
4019  = '8520 '
4021  = '6200 '
4023  = '04023'
4025  = '04025'
4027  = '9360 '
5000  = '05000'
5001  = '05001'
5003  = '05003'
5005  = '05005'
5007  = '2580 '
5009  = '05009'
5011  = '05011'
5013  = '05013'
5015  = '05015'
5017  = '05017'
5019  = '05019'
5021  = '05021'
5023  = '05023'
5025  = '05025'
5027  = '05027'
5029  = '05029'
5031  = '3700 '
5033  = '2720 '
5035  = '4920 '
5037  = '05037'
5039  = '05039'
5041  = '05041'
5043  = '05043'
5045  = '4400 '
5047  = '05047'
5049  = '05049'
5051  = '05051'
5053  = '05053'
5055  = '05055'
5057  = '05057'
5059  = '05059'
5061  = '05061'
5063  = '05063'
5065  = '05065'
5067  = '05067'
5069  = '6240 '
5071  = '05071'
5073  = '05073'
5075  = '05075'
5077  = '05077'
5079  = '05079'
5081  = '05081'
5083  = '05083'
5085  = '4400 '
5087  = '05087'
5089  = '05089'
5091  = '8360 '
5093  = '05093'
5095  = '05095'
5097  = '05097'
5099  = '05099'
5101  = '05101'
5103  = '05103'
5105  = '05105'
5107  = '05107'
5109  = '05109'
5111  = '05111'
5113  = '05113'
5115  = '05115'
5117  = '05117'
5119  = '4400 '
5121  = '05121'
5123  = '05123'
5125  = '4400 '
5127  = '05127'
5129  = '05129'
5131  = '2720 '
5133  = '05133'
5135  = '05135'
5137  = '05137'
5139  = '05139'
5141  = '05141'
5143  = '2580 '
5145  = '05145'
5147  = '05147'
5149  = '05149'
6000  = '06000'
6001  = '7362 '
6003  = '06003'
6005  = '06005'
6007  = '1620 '
6009  = '06009'
6011  = '06011'
6013  = '7362 '
6015  = '06015'
6017  = '6922 '
6019  = '2840 '
6021  = '06021'
6023  = '06023'
6025  = '06025'
6027  = '06027'
6029  = '0680 '
6031  = '06031'
6033  = '06033'
6035  = '06035'
6037  = '4472 '
6039  = '2840 '
6041  = '7362 '
6043  = '06043'
6045  = '06045'
6047  = '4940 '
6049  = '06049'
6051  = '06051'
6053  = '7120 '
6055  = '7362 '
6057  = '06057'
6059  = '4472 '
6061  = '6922 '
6063  = '06063'
6065  = '4472 '
6067  = '6922 '
6069  = '06069'
6071  = '4472 '
6073  = '7320 '
6075  = '7362 '
6077  = '8120 '
6079  = '7460 '
6081  = '7362 '
6083  = '7480 '
6085  = '7362 '
6087  = '7362 '
6089  = '6690 '
6091  = '06091'
6093  = '06093'
6095  = '7362 '
6097  = '7362 '
6099  = '5170 '
6101  = '9340 '
6103  = '06103'
6105  = '06105'
6107  = '8780 '
6109  = '06109'
6111  = '4472 '
6113  = '6922 '
6115  = '9340 '
8000  = '08000'
8001  = '2082 '
8003  = '08003'
8005  = '2082 '
8007  = '08007'
8009  = '08009'
8011  = '08011'
8013  = '2082 '
8014  = '2082 '
8015  = '08015'
8017  = '08017'
8019  = '08019'
8021  = '08021'
8023  = '08023'
8025  = '08025'
8027  = '08027'
8029  = '08029'
8031  = '2082 '
8033  = '08033'
8035  = '2082 '
8037  = '08037'
8039  = '08039'
8041  = '1720 '
8043  = '08043'
8045  = '08045'
8047  = '08047'
8049  = '08049'
8051  = '08051'
8053  = '08053'
8055  = '08055'
8057  = '08057'
8059  = '2082 '
8061  = '08061'
8063  = '08063'
8065  = '08065'
8067  = '08067'
8069  = '2670 '
8071  = '08071'
8073  = '08073'
8075  = '08075'
8077  = '2995 '
8079  = '08079'
8081  = '08081'
8083  = '08083'
8085  = '08085'
8087  = '08087'
8089  = '08089'
8091  = '08091'
8093  = '08093'
8095  = '08095'
8097  = '08097'
8099  = '08099'
8101  = '6560 '
8103  = '08103'
8105  = '08105'
8107  = '08107'
8109  = '08109'
8111  = '08111'
8113  = '08113'
8115  = '08115'
8117  = '08117'
8119  = '08119'
8121  = '08121'
8123  = '2082 '
8125  = '08125'
9000  = '09000'
9001  = '5483 '
9003  = '3283 '
9005  = '09005'
9007  = '3283 '
9009  = '5483 '
9011  = '5523 '
9013  = '3283 '
9015  = '09015'
10000 = '10000'
10001 = '2190 '
10003 = '6162 '
10005 = '10005'
11000 = '11000'
11001 = '8872 '
12000 = '12000'
12001 = '2900 '
12003 = '12003'
12005 = '6015 '
12007 = '12007'
12009 = '4900 '
12011 = '4992 '
12013 = '12013'
12015 = '6580 '
12017 = '12017'
12019 = '3600 '
12021 = '5345 '
12023 = '12023'
12025 = '4992 '
12027 = '12027'
12029 = '12029'
12031 = '3600 '
12033 = '6080 '
12035 = '2020 '
12037 = '12037'
12039 = '8240 '
12041 = '12041'
12043 = '12043'
12045 = '12045'
12047 = '12047'
12049 = '12049'
12051 = '12051'
12053 = '8280 '
12055 = '12055'
12057 = '8280 '
12059 = '12059'
12061 = '12061'
12063 = '12063'
12065 = '12065'
12067 = '12067'
12069 = '5960 '
12071 = '2700 '
12073 = '8240 '
12075 = '12075'
12077 = '12077'
12079 = '12079'
12081 = '7510 '
12083 = '5790 '
12085 = '2710 '
12086 = '4992 '
12087 = '12087'
12089 = '3600 '
12091 = '2750 '
12093 = '12093'
12095 = '5960 '
12097 = '5960 '
12099 = '8960 '
12101 = '8280 '
12103 = '8280 '
12105 = '3980 '
12107 = '12107'
12109 = '3600 '
12111 = '2710 '
12113 = '6080 '
12115 = '7510 '
12117 = '5960 '
12119 = '12119'
12121 = '12121'
12123 = '12123'
12125 = '12125'
12127 = '2020 '
12129 = '12129'
12131 = '12131'
12133 = '12133'
13000 = '13000'
13001 = '13001'
13003 = '13003'
13005 = '13005'
13007 = '13007'
13009 = '13009'
13011 = '13011'
13013 = '0520 '
13015 = '0520 '
13017 = '13017'
13019 = '13019'
13021 = '4680 '
13023 = '13023'
13025 = '13025'
13027 = '13027'
13029 = '7520 '
13031 = '13031'
13033 = '13033'
13035 = '13035'
13037 = '13037'
13039 = '13039'
13043 = '13043'
13045 = '0520 '
13047 = '1560 '
13049 = '13049'
13051 = '7520 '
13053 = '1800 '
13055 = '13055'
13057 = '0520 '
13059 = '0500 '
13061 = '13061'
13063 = '0520 '
13065 = '13065'
13067 = '0520 '
13069 = '13069'
13071 = '13071'
13073 = '0600 '
13075 = '13075'
13077 = '0520 '
13079 = '13079'
13081 = '13081'
13083 = '1560 '
13085 = '13085'
13087 = '13087'
13089 = '0520 '
13091 = '13091'
13093 = '13093'
13095 = '0120 '
13097 = '0520 '
13099 = '13099'
13101 = '13101'
13103 = '7520 '
13105 = '13105'
13107 = '13107'
13109 = '13109'
13111 = '13111'
13113 = '0520 '
13115 = '13115'
13117 = '0520 '
13119 = '13119'
13121 = '0520 '
13123 = '13123'
13125 = '13125'
13127 = '13127'
13129 = '13129'
13131 = '13131'
13133 = '13133'
13135 = '0520 '
13137 = '13137'
13139 = '13139'
13141 = '13141'
13143 = '13143'
13145 = '1800 '
13147 = '13147'
13149 = '13149'
13151 = '0520 '
13153 = '4680 '
13155 = '13155'
13157 = '13157'
13159 = '13159'
13161 = '13161'
13163 = '13163'
13165 = '13165'
13167 = '13167'
13169 = '4680 '
13171 = '13171'
13173 = '13173'
13175 = '13175'
13177 = '0120 '
13179 = '13179'
13181 = '13181'
13183 = '13183'
13185 = '13185'
13187 = '13187'
13189 = '0600 '
13191 = '13191'
13193 = '13193'
13195 = '0500 '
13197 = '13197'
13199 = '13199'
13201 = '13201'
13205 = '13205'
13207 = '13207'
13209 = '13209'
13211 = '13211'
13213 = '13213'
13215 = '1800 '
13217 = '0520 '
13219 = '0500 '
13221 = '13221'
13223 = '0520 '
13225 = '4680 '
13227 = '0520 '
13229 = '13229'
13231 = '13231'
13233 = '13233'
13235 = '13235'
13237 = '13237'
13239 = '13239'
13241 = '13241'
13243 = '13243'
13245 = '0600 '
13247 = '0520 '
13249 = '13249'
13251 = '13251'
13253 = '13253'
13255 = '0520 '
13257 = '13257'
13259 = '13259'
13261 = '13261'
13263 = '13263'
13265 = '13265'
13267 = '13267'
13269 = '13269'
13271 = '13271'
13273 = '13273'
13275 = '13275'
13277 = '13277'
13279 = '13279'
13281 = '13281'
13283 = '13283'
13285 = '13285'
13287 = '13287'
13289 = '4680 '
13291 = '13291'
13293 = '13293'
13295 = '1560 '
13297 = '0520 '
13299 = '13299'
13301 = '13301'
13303 = '13303'
13305 = '13305'
13307 = '13307'
13309 = '13309'
13311 = '13311'
13313 = '13313'
13315 = '13315'
13317 = '13317'
13319 = '13319'
13321 = '13321'
15000 = '15000'
15001 = '15001'
15003 = '3320 '
15005 = '15005'
15007 = '15007'
15009 = '15009'
16000 = '16000'
16001 = '1080 '
16003 = '16003'
16005 = '6340 '
16007 = '16007'
16009 = '16009'
16011 = '16011'
16013 = '16013'
16015 = '16015'
16017 = '16017'
16019 = '16019'
16021 = '16021'
16023 = '16023'
16025 = '16025'
16027 = '1080 '
16029 = '16029'
16031 = '16031'
16033 = '16033'
16035 = '16035'
16037 = '16037'
16039 = '16039'
16041 = '16041'
16043 = '16043'
16045 = '16045'
16047 = '16047'
16049 = '16049'
16051 = '16051'
16053 = '16053'
16055 = '16055'
16057 = '16057'
16059 = '16059'
16061 = '16061'
16063 = '16063'
16065 = '16065'
16067 = '16067'
16069 = '16069'
16071 = '16071'
16073 = '16073'
16075 = '16075'
16077 = '16077'
16079 = '16079'
16081 = '16081'
16083 = '16083'
16085 = '16085'
16087 = '16087'
17000 = '17000'
17001 = '17001'
17003 = '17003'
17005 = '17005'
17007 = '6880 '
17009 = '17009'
17011 = '17011'
17013 = '17013'
17015 = '17015'
17017 = '17017'
17019 = '1400 '
17021 = '17021'
17023 = '17023'
17025 = '17025'
17027 = '7040 '
17029 = '17029'
17031 = '1602 '
17033 = '17033'
17035 = '17035'
17037 = '1602 '
17039 = '17039'
17041 = '17041'
17043 = '1602 '
17045 = '17045'
17047 = '17047'
17049 = '17049'
17051 = '17051'
17053 = '17053'
17055 = '17055'
17057 = '17057'
17059 = '17059'
17061 = '17061'
17063 = '1602 '
17065 = '17065'
17067 = '17067'
17069 = '17069'
17071 = '17071'
17073 = '1960 '
17075 = '17075'
17077 = '17077'
17079 = '17079'
17081 = '17081'
17083 = '7040 '
17085 = '17085'
17087 = '17087'
17089 = '1602 '
17091 = '1602 '
17093 = '1602 '
17095 = '17095'
17097 = '1602 '
17099 = '17099'
17101 = '17101'
17103 = '17103'
17105 = '17105'
17107 = '17107'
17109 = '17109'
17111 = '1602 '
17113 = '1040 '
17115 = '2040 '
17117 = '17117'
17119 = '7040 '
17121 = '17121'
17123 = '17123'
17125 = '17125'
17127 = '17127'
17129 = '7880 '
17131 = '17131'
17133 = '7040 '
17135 = '17135'
17137 = '17137'
17139 = '17139'
17141 = '6880 '
17143 = '6120 '
17145 = '17145'
17147 = '17147'
17149 = '17149'
17151 = '17151'
17153 = '17153'
17155 = '17155'
17157 = '17157'
17159 = '17159'
17161 = '1960 '
17163 = '7040 '
17165 = '17165'
17167 = '7880 '
17169 = '17169'
17171 = '17171'
17173 = '17173'
17175 = '17175'
17177 = '17177'
17179 = '6120 '
17181 = '17181'
17183 = '17183'
17185 = '17185'
17187 = '17187'
17189 = '17189'
17191 = '17191'
17193 = '17193'
17195 = '17195'
17197 = '1602 '
17199 = '17199'
17201 = '6880 '
17203 = '6120 '
18000 = '18000'
18001 = '2760 '
18003 = '2760 '
18005 = '18005'
18007 = '18007'
18009 = '18009'
18011 = '3480 '
18013 = '18013'
18015 = '18015'
18017 = '18017'
18019 = '4520 '
18021 = '8320 '
18023 = '3920 '
18025 = '18025'
18027 = '18027'
18029 = '1642 '
18031 = '18031'
18033 = '2760 '
18035 = '5280 '
18037 = '18037'
18039 = '2330 '
18041 = '18041'
18043 = '4520 '
18045 = '18045'
18047 = '18047'
18049 = '18049'
18051 = '18051'
18053 = '18053'
18055 = '18055'
18057 = '3480 '
18059 = '3480 '
18061 = '4520 '
18063 = '3480 '
18065 = '18065'
18067 = '3850 '
18069 = '2760 '
18071 = '18071'
18073 = '18073'
18075 = '18075'
18077 = '18077'
18079 = '18079'
18081 = '3480 '
18083 = '18083'
18085 = '18085'
18087 = '18087'
18089 = '1602 '
18091 = '18091'
18093 = '18093'
18095 = '3480 '
18097 = '3480 '
18099 = '18099'
18101 = '18101'
18103 = '18103'
18105 = '1020 '
18107 = '18107'
18109 = '3480 '
18111 = '18111'
18113 = '18113'
18115 = '1642 '
18117 = '18117'
18119 = '18119'
18121 = '18121'
18123 = '18123'
18125 = '18125'
18127 = '1602 '
18129 = '2440 '
18131 = '18131'
18133 = '18133'
18135 = '18135'
18137 = '18137'
18139 = '18139'
18141 = '7800 '
18143 = '4520 '
18145 = '3480 '
18147 = '18147'
18149 = '18149'
18151 = '18151'
18153 = '18153'
18155 = '18155'
18157 = '3920 '
18159 = '3850 '
18161 = '18161'
18163 = '2440 '
18165 = '8320 '
18167 = '8320 '
18169 = '18169'
18171 = '18171'
18173 = '2440 '
18175 = '18175'
18177 = '18177'
18179 = '2760 '
18181 = '18181'
18183 = '2760 '
19000 = '19000'
19001 = '19001'
19003 = '19003'
19005 = '19005'
19007 = '19007'
19009 = '19009'
19011 = '19011'
19013 = '8920 '
19015 = '19015'
19017 = '19017'
19019 = '19019'
19021 = '19021'
19023 = '19023'
19025 = '19025'
19027 = '19027'
19029 = '19029'
19031 = '19031'
19033 = '19033'
19035 = '19035'
19037 = '19037'
19039 = '19039'
19041 = '19041'
19043 = '19043'
19045 = '19045'
19047 = '19047'
19049 = '2120 '
19051 = '19051'
19053 = '19053'
19055 = '19055'
19057 = '19057'
19059 = '19059'
19061 = '2200 '
19063 = '19063'
19065 = '19065'
19067 = '19067'
19069 = '19069'
19071 = '19071'
19073 = '19073'
19075 = '19075'
19077 = '19077'
19079 = '19079'
19081 = '19081'
19083 = '19083'
19085 = '19085'
19087 = '19087'
19089 = '19089'
19091 = '19091'
19093 = '19093'
19095 = '19095'
19097 = '19097'
19099 = '19099'
19101 = '19101'
19103 = '3500 '
19105 = '19105'
19107 = '19107'
19109 = '19109'
19111 = '19111'
19113 = '1360 '
19115 = '19115'
19117 = '19117'
19119 = '19119'
19121 = '19121'
19123 = '19123'
19125 = '19125'
19127 = '19127'
19129 = '19129'
19131 = '19131'
19133 = '19133'
19135 = '19135'
19137 = '19137'
19139 = '19139'
19141 = '19141'
19143 = '19143'
19145 = '19145'
19147 = '19147'
19149 = '19149'
19151 = '19151'
19153 = '2120 '
19155 = '5920 '
19157 = '19157'
19159 = '19159'
19161 = '19161'
19163 = '1960 '
19165 = '19165'
19167 = '19167'
19169 = '19169'
19171 = '19171'
19173 = '19173'
19175 = '19175'
19177 = '19177'
19179 = '19179'
19181 = '2120 '
19183 = '19183'
19185 = '19185'
19187 = '19187'
19189 = '19189'
19191 = '19191'
19193 = '7720 '
19195 = '19195'
19197 = '19197'
20000 = '20000'
20001 = '20001'
20003 = '20003'
20005 = '20005'
20007 = '20007'
20009 = '20009'
20011 = '20011'
20013 = '20013'
20015 = '9040 '
20017 = '20017'
20019 = '20019'
20021 = '20021'
20023 = '20023'
20025 = '20025'
20027 = '20027'
20029 = '20029'
20031 = '20031'
20033 = '20033'
20035 = '20035'
20037 = '20037'
20039 = '20039'
20041 = '20041'
20043 = '20043'
20045 = '4150 '
20047 = '20047'
20049 = '20049'
20051 = '20051'
20053 = '20053'
20055 = '20055'
20057 = '20057'
20059 = '20059'
20061 = '20061'
20063 = '20063'
20065 = '20065'
20067 = '20067'
20069 = '20069'
20071 = '20071'
20073 = '20073'
20075 = '20075'
20077 = '20077'
20079 = '9040 '
20081 = '20081'
20083 = '20083'
20085 = '20085'
20087 = '20087'
20089 = '20089'
20091 = '3760 '
20093 = '20093'
20095 = '20095'
20097 = '20097'
20099 = '20099'
20101 = '20101'
20103 = '3760 '
20105 = '20105'
20107 = '20107'
20109 = '20109'
20111 = '20111'
20113 = '20113'
20115 = '20115'
20117 = '20117'
20119 = '20119'
20121 = '3760 '
20123 = '20123'
20125 = '20125'
20127 = '20127'
20129 = '20129'
20131 = '20131'
20133 = '20133'
20135 = '20135'
20137 = '20137'
20139 = '20139'
20141 = '20141'
20143 = '20143'
20145 = '20145'
20147 = '20147'
20149 = '20149'
20151 = '20151'
20153 = '20153'
20155 = '20155'
20157 = '20157'
20159 = '20159'
20161 = '20161'
20163 = '20163'
20165 = '20165'
20167 = '20167'
20169 = '20169'
20171 = '20171'
20173 = '9040 '
20175 = '20175'
20177 = '8440 '
20179 = '20179'
20181 = '20181'
20183 = '20183'
20185 = '20185'
20187 = '20187'
20189 = '20189'
20191 = '20191'
20193 = '20193'
20195 = '20195'
20197 = '20197'
20199 = '20199'
20201 = '20201'
20203 = '20203'
20205 = '20205'
20207 = '20207'
20209 = '3760 '
21000 = '21000'
21001 = '21001'
21003 = '21003'
21005 = '21005'
21007 = '21007'
21009 = '21009'
21011 = '21011'
21013 = '21013'
21015 = '1642 '
21017 = '4280 '
21019 = '3400 '
21021 = '21021'
21023 = '21023'
21025 = '21025'
21027 = '21027'
21029 = '4520 '
21031 = '21031'
21033 = '21033'
21035 = '21035'
21037 = '1642 '
21039 = '21039'
21041 = '21041'
21043 = '3400 '
21045 = '21045'
21047 = '1660 '
21049 = '4280 '
21051 = '21051'
21053 = '21053'
21055 = '21055'
21057 = '21057'
21059 = '5990 '
21061 = '21061'
21063 = '21063'
21065 = '21065'
21067 = '4280 '
21069 = '21069'
21071 = '21071'
21073 = '21073'
21075 = '21075'
21077 = '1642 '
21079 = '21079'
21081 = '1642 '
21083 = '21083'
21085 = '21085'
21087 = '21087'
21089 = '3400 '
21091 = '21091'
21093 = '21093'
21095 = '21095'
21097 = '21097'
21099 = '21099'
21101 = '2440 '
21103 = '21103'
21105 = '21105'
21107 = '21107'
21109 = '21109'
21111 = '4520 '
21113 = '4280 '
21115 = '21115'
21117 = '1642 '
21119 = '21119'
21121 = '21121'
21123 = '21123'
21125 = '21125'
21127 = '21127'
21129 = '21129'
21131 = '21131'
21133 = '21133'
21135 = '21135'
21137 = '21137'
21139 = '21139'
21141 = '21141'
21143 = '21143'
21145 = '21145'
21147 = '21147'
21149 = '21149'
21151 = '4280 '
21153 = '21153'
21155 = '21155'
21157 = '21157'
21159 = '21159'
21161 = '21161'
21163 = '21163'
21165 = '21165'
21167 = '21167'
21169 = '21169'
21171 = '21171'
21173 = '21173'
21175 = '21175'
21177 = '21177'
21179 = '21179'
21181 = '21181'
21183 = '21183'
21185 = '4520 '
21187 = '21187'
21189 = '21189'
21191 = '1642 '
21193 = '21193'
21195 = '21195'
21197 = '21197'
21199 = '21199'
21201 = '21201'
21203 = '21203'
21205 = '21205'
21207 = '21207'
21209 = '4280 '
21211 = '21211'
21213 = '21213'
21215 = '21215'
21217 = '21217'
21219 = '21219'
21221 = '21221'
21223 = '21223'
21225 = '21225'
21227 = '21227'
21229 = '21229'
21231 = '21231'
21233 = '21233'
21235 = '21235'
21237 = '21237'
21239 = '4280 '
22000 = '22000'
22001 = '3880 '
22003 = '22003'
22005 = '0760 '
22007 = '22007'
22009 = '22009'
22011 = '22011'
22013 = '22013'
22015 = '7680 '
22017 = '7680 '
22019 = '3960 '
22021 = '22021'
22023 = '22023'
22025 = '22025'
22027 = '22027'
22029 = '22029'
22031 = '22031'
22033 = '0760 '
22035 = '22035'
22037 = '22037'
22039 = '22039'
22041 = '22041'
22043 = '22043'
22045 = '22045'
22047 = '22047'
22049 = '22049'
22051 = '5560 '
22053 = '22053'
22055 = '3880 '
22057 = '3350 '
22059 = '22059'
22061 = '22061'
22063 = '0760 '
22065 = '22065'
22067 = '22067'
22069 = '22069'
22071 = '5560 '
22073 = '5200 '
22075 = '5560 '
22077 = '22077'
22079 = '0220 '
22081 = '22081'
22083 = '22083'
22085 = '22085'
22087 = '5560 '
22089 = '5560 '
22091 = '22091'
22093 = '5560 '
22095 = '5560 '
22097 = '3880 '
22099 = '3880 '
22101 = '22101'
22103 = '5560 '
22105 = '22105'
22107 = '22107'
22109 = '3350 '
22111 = '22111'
22113 = '22113'
22115 = '22115'
22117 = '22117'
22119 = '7680 '
22121 = '0760 '
22123 = '22123'
22125 = '22125'
22127 = '22127'
23000 = '23000'
23001 = '4243 '
23003 = '23003'
23005 = '6403 '
23007 = '23007'
23009 = '23009'
23011 = '23011'
23013 = '23013'
23015 = '23015'
23017 = '23017'
23019 = '0733 '
23021 = '23021'
23023 = '23023'
23025 = '23025'
23027 = '23027'
23029 = '23029'
23031 = '23031'
24000 = '24000'
24001 = '1900 '
24003 = '8872 '
24005 = '8872 '
24009 = '8872 '
24011 = '24011'
24013 = '8872 '
24015 = '6162 '
24017 = '8872 '
24019 = '24019'
24021 = '8872 '
24023 = '24023'
24025 = '8872 '
24027 = '8872 '
24029 = '24029'
24031 = '8872 '
24033 = '8872 '
24035 = '8872 '
24037 = '24037'
24039 = '24039'
24041 = '24041'
24043 = '8872 '
24045 = '24045'
24047 = '24047'
24510 = '8872 '
25000 = '25000'
25001 = '0743 '
25003 = '6323 '
25005 = '1123 '
25007 = '25007'
25009 = '1123 '
25011 = '25011'
25013 = '8003 '
25015 = '8003 '
25017 = '1123 '
25019 = '25019'
25021 = '1123 '
25023 = '1123 '
25025 = '1123 '
25027 = '1123 '
26000 = '26000'
26001 = '26001'
26003 = '26003'
26005 = '3000 '
26007 = '26007'
26009 = '26009'
26011 = '26011'
26013 = '26013'
26015 = '26015'
26017 = '6960 '
26019 = '26019'
26021 = '0870 '
26023 = '26023'
26025 = '3720 '
26027 = '26027'
26029 = '26029'
26031 = '26031'
26033 = '26033'
26035 = '26035'
26037 = '4040 '
26039 = '26039'
26041 = '26041'
26043 = '26043'
26045 = '4040 '
26047 = '26047'
26049 = '2162 '
26051 = '26051'
26053 = '26053'
26055 = '26055'
26057 = '26057'
26059 = '26059'
26061 = '26061'
26063 = '26063'
26065 = '4040 '
26067 = '26067'
26069 = '26069'
26071 = '26071'
26073 = '26073'
26075 = '3520 '
26077 = '3720 '
26079 = '26079'
26081 = '3000 '
26083 = '26083'
26085 = '26085'
26087 = '2162 '
26089 = '26089'
26091 = '2162 '
26093 = '2162 '
26095 = '26095'
26097 = '26097'
26099 = '2162 '
26101 = '26101'
26103 = '26103'
26105 = '26105'
26107 = '26107'
26109 = '26109'
26111 = '6960 '
26113 = '26113'
26115 = '2162 '
26117 = '26117'
26119 = '26119'
26121 = '3000 '
26123 = '26123'
26125 = '2162 '
26127 = '26127'
26129 = '26129'
26131 = '26131'
26133 = '26133'
26135 = '26135'
26137 = '26137'
26139 = '3000 '
26141 = '26141'
26143 = '26143'
26145 = '6960 '
26147 = '2162 '
26149 = '26149'
26151 = '26151'
26153 = '26153'
26155 = '26155'
26157 = '26157'
26159 = '3720 '
26161 = '2162 '
26163 = '2162 '
26165 = '26165'
27000 = '27000'
27001 = '27001'
27003 = '5120 '
27005 = '27005'
27007 = '27007'
27009 = '6980 '
27011 = '27011'
27013 = '27013'
27015 = '27015'
27017 = '27017'
27019 = '5120 '
27021 = '27021'
27023 = '27023'
27025 = '5120 '
27027 = '2520 '
27029 = '27029'
27031 = '27031'
27033 = '27033'
27035 = '27035'
27037 = '5120 '
27039 = '27039'
27041 = '27041'
27043 = '27043'
27045 = '27045'
27047 = '27047'
27049 = '27049'
27051 = '27051'
27053 = '5120 '
27055 = '3870 '
27057 = '27057'
27059 = '5120 '
27061 = '27061'
27063 = '27063'
27065 = '27065'
27067 = '27067'
27069 = '27069'
27071 = '27071'
27073 = '27073'
27075 = '27075'
27077 = '27077'
27079 = '27079'
27081 = '27081'
27083 = '27083'
27085 = '27085'
27087 = '27087'
27089 = '27089'
27091 = '27091'
27093 = '27093'
27095 = '27095'
27097 = '27097'
27099 = '27099'
27101 = '27101'
27103 = '27103'
27105 = '27105'
27107 = '27107'
27109 = '6820 '
27111 = '27111'
27113 = '27113'
27115 = '27115'
27117 = '27117'
27119 = '2985 '
27121 = '27121'
27123 = '5120 '
27125 = '27125'
27127 = '27127'
27129 = '27129'
27131 = '27131'
27133 = '27133'
27135 = '27135'
27137 = '2240 '
27139 = '5120 '
27141 = '5120 '
27143 = '27143'
27145 = '6980 '
27147 = '27147'
27149 = '27149'
27151 = '27151'
27153 = '27153'
27155 = '27155'
27157 = '27157'
27159 = '27159'
27161 = '27161'
27163 = '5120 '
27165 = '27165'
27167 = '27167'
27169 = '27169'
27171 = '5120 '
27173 = '27173'
28000 = '28000'
28001 = '28001'
28003 = '28003'
28005 = '28005'
28007 = '28007'
28009 = '28009'
28011 = '28011'
28013 = '28013'
28015 = '28015'
28017 = '28017'
28019 = '28019'
28021 = '28021'
28023 = '28023'
28025 = '28025'
28027 = '28027'
28029 = '28029'
28031 = '28031'
28033 = '4920 '
28035 = '3285 '
28037 = '28037'
28039 = '28039'
28041 = '28041'
28043 = '28043'
28045 = '0920 '
28047 = '0920 '
28049 = '3560 '
28051 = '28051'
28053 = '28053'
28055 = '28055'
28057 = '28057'
28059 = '0920 '
28061 = '28061'
28063 = '28063'
28065 = '28065'
28067 = '28067'
28069 = '28069'
28071 = '28071'
28073 = '3285 '
28075 = '28075'
28077 = '28077'
28079 = '28079'
28081 = '28081'
28083 = '28083'
28085 = '28085'
28087 = '28087'
28089 = '3560 '
28091 = '28091'
28093 = '28093'
28095 = '28095'
28097 = '28097'
28099 = '28099'
28101 = '28101'
28103 = '28103'
28105 = '28105'
28107 = '28107'
28109 = '28109'
28111 = '28111'
28113 = '28113'
28115 = '28115'
28117 = '28117'
28119 = '28119'
28121 = '3560 '
28123 = '28123'
28125 = '28125'
28127 = '28127'
28129 = '28129'
28131 = '28131'
28133 = '28133'
28135 = '28135'
28137 = '28137'
28139 = '28139'
28141 = '28141'
28143 = '28143'
28145 = '28145'
28147 = '28147'
28149 = '28149'
28151 = '28151'
28153 = '28153'
28155 = '28155'
28157 = '28157'
28159 = '28159'
28161 = '28161'
28163 = '28163'
29000 = '29000'
29001 = '29001'
29003 = '7000 '
29005 = '29005'
29007 = '29007'
29009 = '29009'
29011 = '29011'
29013 = '29013'
29015 = '29015'
29017 = '29017'
29019 = '1740 '
29021 = '7000 '
29023 = '29023'
29025 = '29025'
29027 = '29027'
29029 = '29029'
29031 = '29031'
29033 = '29033'
29035 = '29035'
29037 = '3760 '
29039 = '29039'
29041 = '29041'
29043 = '7920 '
29045 = '29045'
29047 = '3760 '
29049 = '3760 '
29051 = '29051'
29053 = '29053'
29055 = '7040 '
29057 = '29057'
29059 = '29059'
29061 = '29061'
29063 = '29063'
29065 = '29065'
29067 = '29067'
29069 = '29069'
29071 = '7040 '
29073 = '29073'
29075 = '29075'
29077 = '7920 '
29079 = '29079'
29081 = '29081'
29083 = '29083'
29085 = '29085'
29087 = '29087'
29089 = '29089'
29091 = '29091'
29093 = '29093'
29095 = '3760 '
29097 = '3710 '
29099 = '7040 '
29101 = '29101'
29103 = '29103'
29105 = '29105'
29107 = '3760 '
29109 = '29109'
29111 = '29111'
29113 = '7040 '
29115 = '29115'
29117 = '29117'
29119 = '29119'
29121 = '29121'
29123 = '29123'
29125 = '29125'
29127 = '29127'
29129 = '29129'
29131 = '29131'
29133 = '29133'
29135 = '29135'
29137 = '29137'
29139 = '29139'
29141 = '29141'
29143 = '29143'
29145 = '3710 '
29147 = '29147'
29149 = '29149'
29151 = '29151'
29153 = '29153'
29155 = '29155'
29157 = '29157'
29159 = '29159'
29161 = '29161'
29163 = '29163'
29165 = '3760 '
29167 = '29167'
29169 = '29169'
29171 = '29171'
29173 = '29173'
29175 = '29175'
29177 = '3760 '
29179 = '29179'
29181 = '29181'
29183 = '7040 '
29185 = '29185'
29186 = '29186'
29187 = '29187'
29189 = '7040 '
29195 = '29195'
29197 = '29197'
29199 = '29199'
29201 = '29201'
29203 = '29203'
29205 = '29205'
29207 = '29207'
29209 = '29209'
29211 = '29211'
29213 = '29213'
29215 = '29215'
29217 = '29217'
29219 = '7040 '
29221 = '29221'
29223 = '29223'
29225 = '7920 '
29227 = '29227'
29229 = '29229'
29510 = '7040 '
30000 = '30000'
30001 = '30001'
30003 = '30003'
30005 = '30005'
30007 = '30007'
30009 = '30009'
30011 = '30011'
30013 = '3040 '
30015 = '30015'
30017 = '30017'
30019 = '30019'
30021 = '30021'
30023 = '30023'
30025 = '30025'
30027 = '30027'
30029 = '30029'
30031 = '30031'
30033 = '30033'
30035 = '30035'
30037 = '30037'
30039 = '30039'
30041 = '30041'
30043 = '30043'
30045 = '30045'
30047 = '30047'
30049 = '30049'
30051 = '30051'
30053 = '30053'
30055 = '30055'
30057 = '30057'
30059 = '30059'
30061 = '30061'
30063 = '5140 '
30065 = '30065'
30067 = '30067'
30069 = '30069'
30071 = '30071'
30073 = '30073'
30075 = '30075'
30077 = '30077'
30079 = '30079'
30081 = '30081'
30083 = '30083'
30085 = '30085'
30087 = '30087'
30089 = '30089'
30091 = '30091'
30093 = '30093'
30095 = '30095'
30097 = '30097'
30099 = '30099'
30101 = '30101'
30103 = '30103'
30105 = '30105'
30107 = '30107'
30109 = '30109'
30111 = '0880 '
30113 = '30113'
31000 = '31000'
31001 = '31001'
31003 = '31003'
31005 = '31005'
31007 = '31007'
31009 = '31009'
31011 = '31011'
31013 = '31013'
31015 = '31015'
31017 = '31017'
31019 = '31019'
31021 = '31021'
31023 = '31023'
31025 = '5920 '
31027 = '31027'
31029 = '31029'
31031 = '31031'
31033 = '31033'
31035 = '31035'
31037 = '31037'
31039 = '31039'
31041 = '31041'
31043 = '7720 '
31045 = '31045'
31047 = '31047'
31049 = '31049'
31051 = '31051'
31053 = '31053'
31055 = '5920 '
31057 = '31057'
31059 = '31059'
31061 = '31061'
31063 = '31063'
31065 = '31065'
31067 = '31067'
31069 = '31069'
31071 = '31071'
31073 = '31073'
31075 = '31075'
31077 = '31077'
31079 = '31079'
31081 = '31081'
31083 = '31083'
31085 = '31085'
31087 = '31087'
31089 = '31089'
31091 = '31091'
31093 = '31093'
31095 = '31095'
31097 = '31097'
31099 = '31099'
31101 = '31101'
31103 = '31103'
31105 = '31105'
31107 = '31107'
31109 = '4360 '
31111 = '31111'
31113 = '31113'
31115 = '31115'
31117 = '31117'
31119 = '31119'
31121 = '31121'
31123 = '31123'
31125 = '31125'
31127 = '31127'
31129 = '31129'
31131 = '31131'
31133 = '31133'
31135 = '31135'
31137 = '31137'
31139 = '31139'
31141 = '31141'
31143 = '31143'
31145 = '31145'
31147 = '31147'
31149 = '31149'
31151 = '31151'
31153 = '5920 '
31155 = '31155'
31157 = '31157'
31159 = '31159'
31161 = '31161'
31163 = '31163'
31165 = '31165'
31167 = '31167'
31169 = '31169'
31171 = '31171'
31173 = '31173'
31175 = '31175'
31177 = '5920 '
31179 = '31179'
31181 = '31181'
31183 = '31183'
31185 = '31185'
32000 = '32000'
32001 = '32001'
32003 = '4120 '
32005 = '32005'
32007 = '32007'
32009 = '32009'
32011 = '32011'
32013 = '32013'
32015 = '32015'
32017 = '32017'
32019 = '32019'
32021 = '32021'
32023 = '4120 '
32027 = '32027'
32029 = '32029'
32031 = '6720 '
32033 = '32033'
32510 = '32510'
33000 = '33000'
33001 = '33001'
33003 = '33003'
33005 = '33005'
33007 = '33007'
33009 = '33009'
33011 = '1123 '
33013 = '33013'
33015 = '1123 '
33017 = '1123 '
33019 = '33019'
34000 = '34000'
34001 = '6162 '
34003 = '5602 '
34005 = '6162 '
34007 = '6162 '
34009 = '6162 '
34011 = '6162 '
34013 = '5602 '
34015 = '6162 '
34017 = '5602 '
34019 = '5602 '
34021 = '5602 '
34023 = '5602 '
34025 = '5602 '
34027 = '5602 '
34029 = '5602 '
34031 = '5602 '
34033 = '6162 '
34035 = '5602 '
34037 = '5602 '
34039 = '5602 '
34041 = '5602 '
35000 = '35000'
35001 = '0200 '
35003 = '35003'
35005 = '35005'
35006 = '35006'
35007 = '35007'
35009 = '35009'
35011 = '35011'
35013 = '4100 '
35015 = '35015'
35017 = '35017'
35019 = '35019'
35021 = '35021'
35023 = '35023'
35025 = '35025'
35027 = '35027'
35028 = '7490 '
35029 = '35029'
35031 = '35031'
35033 = '35033'
35035 = '35035'
35037 = '35037'
35039 = '35039'
35041 = '35041'
35043 = '0200 '
35045 = '35045'
35047 = '35047'
35049 = '7490 '
35051 = '35051'
35053 = '35053'
35055 = '35055'
35057 = '35057'
35059 = '35059'
35061 = '0200 '
36000 = '36000'
36001 = '0160 '
36003 = '36003'
36005 = '5602 '
36007 = '0960 '
36009 = '36009'
36011 = '8160 '
36013 = '3610 '
36015 = '2335 '
36017 = '36017'
36019 = '36019'
36021 = '36021'
36023 = '36023'
36025 = '36025'
36027 = '5602 '
36029 = '1280 '
36031 = '36031'
36033 = '36033'
36035 = '36035'
36037 = '6840 '
36039 = '36039'
36041 = '36041'
36043 = '8680 '
36045 = '36045'
36047 = '5602 '
36049 = '36049'
36051 = '6840 '
36053 = '8160 '
36055 = '6840 '
36057 = '0160 '
36059 = '5602 '
36061 = '5602 '
36063 = '1280 '
36065 = '8680 '
36067 = '8160 '
36069 = '6840 '
36071 = '5602 '
36073 = '6840 '
36075 = '8160 '
36077 = '36077'
36079 = '5602 '
36081 = '5602 '
36083 = '0160 '
36085 = '5602 '
36087 = '5602 '
36089 = '36089'
36091 = '0160 '
36093 = '0160 '
36095 = '0160 '
36097 = '36097'
36099 = '36099'
36101 = '36101'
36103 = '5602 '
36105 = '36105'
36107 = '0960 '
36109 = '36109'
36111 = '36111'
36113 = '2975 '
36115 = '2975 '
36117 = '6840 '
36119 = '5602 '
36121 = '36121'
36123 = '36123'
37000 = '37000'
37001 = '3120 '
37003 = '3290 '
37005 = '37005'
37007 = '37007'
37009 = '37009'
37011 = '37011'
37013 = '37013'
37015 = '37015'
37017 = '37017'
37019 = '9200 '
37021 = '0480 '
37023 = '3290 '
37025 = '1520 '
37027 = '3290 '
37029 = '37029'
37031 = '37031'
37033 = '37033'
37035 = '3290 '
37037 = '6640 '
37039 = '37039'
37041 = '37041'
37043 = '37043'
37045 = '37045'
37047 = '37047'
37049 = '37049'
37051 = '2560 '
37053 = '5720 '
37055 = '37055'
37057 = '3120 '
37059 = '3120 '
37061 = '37061'
37063 = '6640 '
37065 = '6895 '
37067 = '3120 '
37069 = '6640 '
37071 = '1520 '
37073 = '37073'
37075 = '37075'
37077 = '37077'
37079 = '37079'
37081 = '3120 '
37083 = '37083'
37085 = '37085'
37087 = '37087'
37089 = '37089'
37091 = '37091'
37093 = '37093'
37095 = '37095'
37097 = '37097'
37099 = '37099'
37101 = '6640 '
37103 = '37103'
37105 = '37105'
37107 = '37107'
37109 = '1520 '
37111 = '37111'
37113 = '37113'
37115 = '0480 '
37117 = '37117'
37119 = '1520 '
37121 = '37121'
37123 = '37123'
37125 = '37125'
37127 = '6895 '
37129 = '9200 '
37131 = '37131'
37133 = '3605 '
37135 = '6640 '
37137 = '37137'
37139 = '37139'
37141 = '37141'
37143 = '37143'
37145 = '37145'
37147 = '3150 '
37149 = '37149'
37151 = '3120 '
37153 = '37153'
37155 = '37155'
37157 = '37157'
37159 = '1520 '
37161 = '37161'
37163 = '37163'
37165 = '37165'
37167 = '37167'
37169 = '3120 '
37171 = '37171'
37173 = '37173'
37175 = '37175'
37177 = '37177'
37179 = '1520 '
37181 = '37181'
37183 = '6640 '
37185 = '37185'
37187 = '37187'
37189 = '37189'
37191 = '2980 '
37193 = '37193'
37195 = '37195'
37197 = '3120 '
37199 = '37199'
38000 = '38000'
38001 = '38001'
38003 = '38003'
38005 = '38005'
38007 = '38007'
38009 = '38009'
38011 = '38011'
38013 = '38013'
38015 = '1010 '
38017 = '2520 '
38019 = '38019'
38021 = '38021'
38023 = '38023'
38025 = '38025'
38027 = '38027'
38029 = '38029'
38031 = '38031'
38033 = '38033'
38035 = '2985 '
38037 = '38037'
38039 = '38039'
38041 = '38041'
38043 = '38043'
38045 = '38045'
38047 = '38047'
38049 = '38049'
38051 = '38051'
38053 = '38053'
38055 = '38055'
38057 = '38057'
38059 = '1010 '
38061 = '38061'
38063 = '38063'
38065 = '38065'
38067 = '38067'
38069 = '38069'
38071 = '38071'
38073 = '38073'
38075 = '38075'
38077 = '38077'
38079 = '38079'
38081 = '38081'
38083 = '38083'
38085 = '38085'
38087 = '38087'
38089 = '38089'
38091 = '38091'
38093 = '38093'
38095 = '38095'
38097 = '38097'
38099 = '38099'
38101 = '38101'
38103 = '38103'
38105 = '38105'
39000 = '39000'
39001 = '39001'
39003 = '4320 '
39005 = '39005'
39007 = '1692 '
39009 = '39009'
39011 = '4320 '
39013 = '9000 '
39015 = '1642 '
39017 = '1642 '
39019 = '1320 '
39021 = '39021'
39023 = '2000 '
39025 = '1642 '
39027 = '39027'
39029 = '9320 '
39031 = '39031'
39033 = '4800 '
39035 = '1692 '
39037 = '39037'
39039 = '39039'
39041 = '1840 '
39043 = '39043'
39045 = '1840 '
39047 = '39047'
39049 = '1840 '
39051 = '8400 '
39053 = '39053'
39055 = '1692 '
39057 = '2000 '
39059 = '39059'
39061 = '1642 '
39063 = '39063'
39065 = '39065'
39067 = '39067'
39069 = '39069'
39071 = '39071'
39073 = '39073'
39075 = '39075'
39077 = '39077'
39079 = '39079'
39081 = '8080 '
39083 = '39083'
39085 = '1692 '
39087 = '3400 '
39089 = '1840 '
39091 = '39091'
39093 = '1692 '
39095 = '8400 '
39097 = '1840 '
39099 = '9320 '
39101 = '39101'
39103 = '1692 '
39105 = '39105'
39107 = '39107'
39109 = '2000 '
39111 = '39111'
39113 = '2000 '
39115 = '39115'
39117 = '39117'
39119 = '39119'
39121 = '39121'
39123 = '39123'
39125 = '39125'
39127 = '39127'
39129 = '1840 '
39131 = '39131'
39133 = '1692 '
39135 = '39135'
39137 = '39137'
39139 = '4800 '
39141 = '39141'
39143 = '39143'
39145 = '39145'
39147 = '39147'
39149 = '39149'
39151 = '1320 '
39153 = '1692 '
39155 = '9320 '
39157 = '39157'
39159 = '39159'
39161 = '39161'
39163 = '39163'
39165 = '1642 '
39167 = '6020 '
39169 = '39169'
39171 = '39171'
39173 = '8400 '
39175 = '39175'
40000 = '40000'
40001 = '40001'
40003 = '40003'
40005 = '40005'
40007 = '40007'
40009 = '40009'
40011 = '40011'
40013 = '40013'
40015 = '40015'
40017 = '5880 '
40019 = '40019'
40021 = '40021'
40023 = '40023'
40025 = '40025'
40027 = '5880 '
40029 = '40029'
40031 = '4200 '
40033 = '40033'
40035 = '40035'
40037 = '8560 '
40039 = '40039'
40041 = '40041'
40043 = '40043'
40045 = '40045'
40047 = '2340 '
40049 = '40049'
40051 = '40051'
40053 = '40053'
40055 = '40055'
40057 = '40057'
40059 = '40059'
40061 = '40061'
40063 = '40063'
40065 = '40065'
40067 = '40067'
40069 = '40069'
40071 = '40071'
40073 = '40073'
40075 = '40075'
40077 = '40077'
40079 = '40079'
40081 = '40081'
40083 = '5880 '
40085 = '40085'
40087 = '5880 '
40089 = '40089'
40091 = '40091'
40093 = '40093'
40095 = '40095'
40097 = '40097'
40099 = '40099'
40101 = '40101'
40103 = '40103'
40105 = '40105'
40107 = '40107'
40109 = '5880 '
40111 = '40111'
40113 = '8560 '
40115 = '40115'
40117 = '40117'
40119 = '40119'
40121 = '40121'
40123 = '40123'
40125 = '5880 '
40127 = '40127'
40129 = '40129'
40131 = '8560 '
40133 = '40133'
40135 = '2720 '
40137 = '40137'
40139 = '40139'
40141 = '40141'
40143 = '8560 '
40145 = '8560 '
40147 = '40147'
40149 = '40149'
40151 = '40151'
40153 = '40153'
41000 = '41000'
41001 = '41001'
41003 = '1890 '
41005 = '6442 '
41007 = '41007'
41009 = '6442 '
41011 = '41011'
41013 = '41013'
41015 = '41015'
41017 = '41017'
41019 = '41019'
41021 = '41021'
41023 = '41023'
41025 = '41025'
41027 = '41027'
41029 = '4890 '
41031 = '41031'
41033 = '41033'
41035 = '41035'
41037 = '41037'
41039 = '2400 '
41041 = '41041'
41043 = '41043'
41045 = '41045'
41047 = '6442 '
41049 = '41049'
41051 = '6442 '
41053 = '6442 '
41055 = '41055'
41057 = '41057'
41059 = '41059'
41061 = '41061'
41063 = '41063'
41065 = '41065'
41067 = '6442 '
41069 = '41069'
41071 = '6442 '
42000 = '42000'
42001 = '42001'
42003 = '6280 '
42005 = '42005'
42007 = '6280 '
42009 = '42009'
42011 = '6680 '
42013 = '0280 '
42015 = '42015'
42017 = '6162 '
42019 = '6280 '
42021 = '3680 '
42023 = '42023'
42025 = '0240 '
42027 = '8050 '
42029 = '6162 '
42031 = '42031'
42033 = '42033'
42035 = '42035'
42037 = '7560 '
42039 = '42039'
42041 = '3240 '
42043 = '3240 '
42045 = '6162 '
42047 = '42047'
42049 = '2360 '
42051 = '6280 '
42053 = '42053'
42055 = '42055'
42057 = '42057'
42059 = '42059'
42061 = '42061'
42063 = '42063'
42065 = '42065'
42067 = '42067'
42069 = '7560 '
42071 = '4000 '
42073 = '42073'
42075 = '3240 '
42077 = '0240 '
42079 = '7560 '
42081 = '9140 '
42083 = '42083'
42085 = '7610 '
42087 = '42087'
42089 = '42089'
42091 = '6162 '
42093 = '42093'
42095 = '0240 '
42097 = '42097'
42099 = '3240 '
42101 = '6162 '
42103 = '5602 '
42105 = '42105'
42107 = '42107'
42109 = '42109'
42111 = '3680 '
42113 = '42113'
42115 = '42115'
42117 = '42117'
42119 = '42119'
42121 = '42121'
42123 = '42123'
42125 = '6280 '
42127 = '42127'
42129 = '6280 '
42131 = '7560 '
42133 = '9280 '
44000 = '44000'
44001 = '6483 '
44003 = '6483 '
44005 = '44005'
44007 = '6483 '
44009 = '6483 '
45000 = '45000'
45001 = '45001'
45003 = '0600 '
45005 = '45005'
45007 = '3160 '
45009 = '45009'
45011 = '45011'
45013 = '45013'
45015 = '1440 '
45017 = '45017'
45019 = '1440 '
45021 = '3160 '
45023 = '45023'
45025 = '45025'
45027 = '45027'
45029 = '45029'
45031 = '45031'
45033 = '45033'
45035 = '1440 '
45037 = '0600 '
45039 = '45039'
45041 = '2655 '
45043 = '45043'
45045 = '3160 '
45047 = '45047'
45049 = '45049'
45051 = '5330 '
45053 = '45053'
45055 = '45055'
45057 = '45057'
45059 = '45059'
45061 = '45061'
45063 = '1760 '
45065 = '45065'
45067 = '45067'
45069 = '45069'
45071 = '45071'
45073 = '45073'
45075 = '45075'
45077 = '3160 '
45079 = '1760 '
45081 = '45081'
45083 = '3160 '
45085 = '8140 '
45087 = '45087'
45089 = '45089'
45091 = '1520 '
46000 = '46000'
46003 = '46003'
46005 = '46005'
46007 = '46007'
46009 = '46009'
46011 = '46011'
46013 = '46013'
46015 = '46015'
46017 = '46017'
46019 = '46019'
46021 = '46021'
46023 = '46023'
46025 = '46025'
46027 = '46027'
46029 = '46029'
46031 = '46031'
46033 = '46033'
46035 = '46035'
46037 = '46037'
46039 = '46039'
46041 = '46041'
46043 = '46043'
46045 = '46045'
46047 = '46047'
46049 = '46049'
46051 = '46051'
46053 = '46053'
46055 = '46055'
46057 = '46057'
46059 = '46059'
46061 = '46061'
46063 = '46063'
46065 = '46065'
46067 = '46067'
46069 = '46069'
46071 = '46071'
46073 = '46073'
46075 = '46075'
46077 = '46077'
46079 = '46079'
46081 = '46081'
46083 = '7760 '
46085 = '46085'
46087 = '46087'
46089 = '46089'
46091 = '46091'
46093 = '46093'
46095 = '46095'
46097 = '46097'
46099 = '7760 '
46101 = '46101'
46103 = '6660 '
46105 = '46105'
46107 = '46107'
46109 = '46109'
46111 = '46111'
46113 = '46113'
46115 = '46115'
46117 = '46117'
46119 = '46119'
46121 = '46121'
46123 = '46123'
46125 = '46125'
46127 = '46127'
46129 = '46129'
46135 = '46135'
46137 = '46137'
47000 = '47000'
47001 = '3840 '
47003 = '47003'
47005 = '47005'
47007 = '47007'
47009 = '3840 '
47011 = '47011'
47013 = '47013'
47015 = '47015'
47017 = '47017'
47019 = '3660 '
47021 = '5360 '
47023 = '3580 '
47025 = '47025'
47027 = '47027'
47029 = '47029'
47031 = '47031'
47033 = '47033'
47035 = '47035'
47037 = '5360 '
47039 = '47039'
47041 = '47041'
47043 = '5360 '
47045 = '47045'
47047 = '4920 '
47049 = '47049'
47051 = '47051'
47053 = '47053'
47055 = '47055'
47057 = '47057'
47059 = '47059'
47061 = '47061'
47063 = '47063'
47065 = '1560 '
47067 = '47067'
47069 = '47069'
47071 = '47071'
47073 = '3660 '
47075 = '47075'
47077 = '47077'
47079 = '47079'
47081 = '47081'
47083 = '47083'
47085 = '47085'
47087 = '47087'
47089 = '47089'
47091 = '47091'
47093 = '3840 '
47095 = '47095'
47097 = '47097'
47099 = '47099'
47101 = '47101'
47103 = '47103'
47105 = '3840 '
47107 = '47107'
47109 = '47109'
47111 = '47111'
47113 = '3580 '
47115 = '1560 '
47117 = '47117'
47119 = '47119'
47121 = '47121'
47123 = '47123'
47125 = '1660 '
47127 = '47127'
47129 = '47129'
47131 = '47131'
47133 = '47133'
47135 = '47135'
47137 = '47137'
47139 = '47139'
47141 = '47141'
47143 = '47143'
47145 = '47145'
47147 = '5360 '
47149 = '5360 '
47151 = '47151'
47153 = '47153'
47155 = '3840 '
47157 = '4920 '
47159 = '47159'
47161 = '47161'
47163 = '3660 '
47165 = '5360 '
47167 = '4920 '
47169 = '47169'
47171 = '3660 '
47173 = '3840 '
47175 = '47175'
47177 = '47177'
47179 = '3660 '
47181 = '47181'
47183 = '47183'
47185 = '47185'
47187 = '5360 '
47189 = '5360 '
48000 = '48000'
48001 = '48001'
48003 = '48003'
48005 = '48005'
48007 = '48007'
48009 = '9080 '
48011 = '48011'
48013 = '48013'
48015 = '48015'
48017 = '48017'
48019 = '48019'
48021 = '0640 '
48023 = '48023'
48025 = '48025'
48027 = '3810 '
48029 = '7240 '
48031 = '48031'
48033 = '48033'
48035 = '48035'
48037 = '8360 '
48039 = '3362 '
48041 = '1260 '
48043 = '48043'
48045 = '48045'
48047 = '48047'
48049 = '48049'
48051 = '48051'
48053 = '48053'
48055 = '0640 '
48057 = '48057'
48059 = '48059'
48061 = '1240 '
48063 = '48063'
48065 = '48065'
48067 = '48067'
48069 = '48069'
48071 = '3362 '
48073 = '48073'
48075 = '48075'
48077 = '48077'
48079 = '48079'
48081 = '48081'
48083 = '48083'
48085 = '1922 '
48087 = '48087'
48089 = '48089'
48091 = '7240 '
48093 = '48093'
48095 = '48095'
48097 = '48097'
48099 = '3810 '
48101 = '48101'
48103 = '48103'
48105 = '48105'
48107 = '48107'
48109 = '48109'
48111 = '48111'
48113 = '1922 '
48115 = '48115'
48117 = '48117'
48119 = '48119'
48121 = '1922 '
48123 = '48123'
48125 = '48125'
48127 = '48127'
48129 = '48129'
48131 = '48131'
48133 = '48133'
48135 = '5800 '
48137 = '48137'
48139 = '1922 '
48141 = '2320 '
48143 = '48143'
48145 = '48145'
48147 = '48147'
48149 = '48149'
48151 = '48151'
48153 = '48153'
48155 = '48155'
48157 = '3362 '
48159 = '48159'
48161 = '48161'
48163 = '48163'
48165 = '48165'
48167 = '3362 '
48169 = '48169'
48171 = '48171'
48173 = '48173'
48175 = '48175'
48177 = '48177'
48179 = '48179'
48181 = '7640 '
48183 = '4420 '
48185 = '48185'
48187 = '7240 '
48189 = '48189'
48191 = '48191'
48193 = '48193'
48195 = '48195'
48197 = '48197'
48199 = '0840 '
48201 = '3362 '
48203 = '4420 '
48205 = '48205'
48207 = '48207'
48209 = '0640 '
48211 = '48211'
48213 = '1922 '
48215 = '4880 '
48217 = '48217'
48219 = '48219'
48221 = '1922 '
48223 = '48223'
48225 = '48225'
48227 = '48227'
48229 = '48229'
48231 = '1922 '
48233 = '48233'
48235 = '48235'
48237 = '48237'
48239 = '48239'
48241 = '48241'
48243 = '48243'
48245 = '0840 '
48247 = '48247'
48249 = '48249'
48251 = '1922 '
48253 = '48253'
48255 = '48255'
48257 = '1922 '
48259 = '48259'
48261 = '48261'
48263 = '48263'
48265 = '48265'
48267 = '48267'
48269 = '48269'
48271 = '48271'
48273 = '48273'
48275 = '48275'
48277 = '48277'
48279 = '48279'
48281 = '48281'
48283 = '48283'
48285 = '48285'
48287 = '48287'
48289 = '48289'
48291 = '3362 '
48293 = '48293'
48295 = '48295'
48297 = '48297'
48299 = '48299'
48301 = '48301'
48303 = '4600 '
48305 = '48305'
48307 = '48307'
48309 = '8800 '
48311 = '48311'
48313 = '48313'
48315 = '48315'
48317 = '48317'
48319 = '48319'
48321 = '48321'
48323 = '48323'
48325 = '48325'
48327 = '48327'
48329 = '5800 '
48331 = '48331'
48333 = '48333'
48335 = '48335'
48337 = '48337'
48339 = '3362 '
48341 = '48341'
48343 = '48343'
48345 = '48345'
48347 = '48347'
48349 = '48349'
48351 = '48351'
48353 = '48353'
48355 = '1880 '
48357 = '48357'
48359 = '48359'
48361 = '0840 '
48363 = '48363'
48365 = '48365'
48367 = '1922 '
48369 = '48369'
48371 = '48371'
48373 = '48373'
48375 = '0320 '
48377 = '48377'
48379 = '48379'
48381 = '0320 '
48383 = '48383'
48385 = '48385'
48387 = '48387'
48389 = '48389'
48391 = '48391'
48393 = '48393'
48395 = '48395'
48397 = '1922 '
48399 = '48399'
48401 = '48401'
48403 = '48403'
48405 = '48405'
48407 = '48407'
48409 = '1880 '
48411 = '48411'
48413 = '48413'
48415 = '48415'
48417 = '48417'
48419 = '48419'
48421 = '48421'
48423 = '8640 '
48425 = '48425'
48427 = '48427'
48429 = '48429'
48431 = '48431'
48433 = '48433'
48435 = '48435'
48437 = '48437'
48439 = '1922 '
48441 = '0040 '
48443 = '48443'
48445 = '48445'
48447 = '48447'
48449 = '48449'
48451 = '7200 '
48453 = '0640 '
48455 = '48455'
48457 = '48457'
48459 = '4420 '
48461 = '48461'
48463 = '48463'
48465 = '48465'
48467 = '48467'
48469 = '8750 '
48471 = '48471'
48473 = '3362 '
48475 = '48475'
48477 = '48477'
48479 = '4080 '
48481 = '48481'
48483 = '48483'
48485 = '9080 '
48487 = '48487'
48489 = '48489'
48491 = '0640 '
48493 = '7240 '
48495 = '48495'
48497 = '48497'
48499 = '48499'
48501 = '48501'
48503 = '48503'
48505 = '48505'
48507 = '48507'
49000 = '49000'
49001 = '49001'
49003 = '49003'
49005 = '49005'
49007 = '49007'
49009 = '49009'
49011 = '7160 '
49013 = '49013'
49015 = '49015'
49017 = '49017'
49019 = '49019'
49021 = '49021'
49023 = '49023'
49025 = '2620 '
49027 = '49027'
49029 = '49029'
49031 = '49031'
49033 = '49033'
49035 = '7160 '
49037 = '49037'
49039 = '49039'
49041 = '49041'
49043 = '49043'
49045 = '49045'
49047 = '49047'
49049 = '6520 '
49051 = '49051'
49053 = '49053'
49055 = '49055'
49057 = '7160 '
50000 = '50000'
50001 = '50001'
50003 = '50003'
50005 = '50005'
50007 = '1303 '
50009 = '50009'
50011 = '1303 '
50013 = '1303 '
50015 = '50015'
50017 = '50017'
50019 = '50019'
50021 = '50021'
50023 = '50023'
50025 = '50025'
50027 = '50027'
51000 = '51000'
51001 = '51001'
51003 = '1540 '
51005 = '51005'
51007 = '51007'
51009 = '4640 '
51011 = '51011'
51013 = '8872 '
51015 = '51015'
51017 = '51017'
51019 = '4640 '
51021 = '51021'
51023 = '6800 '
51025 = '51025'
51027 = '51027'
51029 = '51029'
51031 = '4640 '
51033 = '51033'
51035 = '51035'
51036 = '6760 '
51037 = '51037'
51041 = '6760 '
51043 = '8872 '
51045 = '51045'
51047 = '8872 '
51049 = '51049'
51051 = '51051'
51053 = '6760 '
51057 = '51057'
51059 = '8872 '
51061 = '8872 '
51063 = '51063'
51065 = '1540 '
51067 = '51067'
51069 = '51069'
51071 = '51071'
51073 = '5720 '
51075 = '6760 '
51077 = '51077'
51079 = '1540 '
51081 = '51081'
51083 = '51083'
51085 = '6760 '
51087 = '6760 '
51089 = '51089'
51091 = '51091'
51093 = '5720 '
51095 = '5720 '
51097 = '51097'
51099 = '8872 '
51101 = '51101'
51103 = '51103'
51105 = '51105'
51107 = '8872 '
51109 = '51109'
51111 = '51111'
51113 = '51113'
51115 = '5720 '
51117 = '51117'
51119 = '51119'
51121 = '51121'
51123 = '5720 '
51125 = '51125'
51127 = '6760 '
51129 = '5720 '
51131 = '51131'
51133 = '51133'
51135 = '51135'
51137 = '51137'
51139 = '51139'
51141 = '51141'
51143 = '1950 '
51145 = '6760 '
51147 = '51147'
51149 = '6760 '
51153 = '8872 '
51155 = '51155'
51157 = '51157'
51159 = '51159'
51161 = '6800 '
51163 = '51163'
51165 = '51165'
51167 = '51167'
51169 = '3660 '
51171 = '51171'
51173 = '51173'
51175 = '51175'
51177 = '8872 '
51179 = '8872 '
51181 = '51181'
51183 = '51183'
51185 = '51185'
51187 = '8872 '
51191 = '3660 '
51193 = '51193'
51195 = '51195'
51197 = '51197'
51199 = '5720 '
51510 = '8872 '
51515 = '4640 '
51520 = '3660 '
51530 = '51530'
51540 = '1540 '
51550 = '5720 '
51560 = '51560'
51570 = '6760 '
51580 = '51580'
51590 = '1950 '
51595 = '51595'
51600 = '8872 '
51610 = '8872 '
51620 = '51620'
51630 = '8872 '
51640 = '51640'
51650 = '5720 '
51660 = '51660'
51670 = '6760 '
51678 = '51678'
51680 = '4640 '
51683 = '8872 '
51685 = '8872 '
51690 = '51690'
51700 = '5720 '
51710 = '5720 '
51720 = '51720'
51730 = '6760 '
51735 = '5720 '
51740 = '5720 '
51750 = '51750'
51760 = '6760 '
51770 = '6800 '
51775 = '6800 '
51780 = '51780'
51790 = '51790'
51800 = '5720 '
51810 = '5720 '
51820 = '51820'
51830 = '5720 '
51840 = '51840'
53000 = '53000'
53001 = '53001'
53003 = '53003'
53005 = '6740 '
53007 = '53007'
53009 = '53009'
53011 = '6442 '
53013 = '53013'
53015 = '53015'
53017 = '53017'
53019 = '53019'
53021 = '6740 '
53023 = '53023'
53025 = '53025'
53027 = '53027'
53029 = '7602 '
53031 = '53031'
53033 = '7602 '
53035 = '7602 '
53037 = '53037'
53039 = '53039'
53041 = '53041'
53043 = '53043'
53045 = '53045'
53047 = '53047'
53049 = '53049'
53051 = '53051'
53053 = '7602 '
53055 = '53055'
53057 = '53057'
53059 = '53059'
53061 = '7602 '
53063 = '7840 '
53065 = '53065'
53067 = '7602 '
53069 = '53069'
53071 = '53071'
53073 = '0860 '
53075 = '53075'
53077 = '9260 '
54000 = '54000'
54001 = '54001'
54003 = '8872 '
54005 = '54005'
54007 = '54007'
54009 = '8080 '
54011 = '3400 '
54013 = '54013'
54015 = '54015'
54017 = '54017'
54019 = '54019'
54021 = '54021'
54023 = '54023'
54025 = '54025'
54027 = '54027'
54029 = '8080 '
54031 = '54031'
54033 = '54033'
54035 = '54035'
54037 = '8872 '
54039 = '1480 '
54041 = '54041'
54043 = '54043'
54045 = '54045'
54047 = '54047'
54049 = '54049'
54051 = '9000 '
54053 = '54053'
54055 = '54055'
54057 = '1900 '
54059 = '54059'
54061 = '54061'
54063 = '54063'
54065 = '54065'
54067 = '54067'
54069 = '9000 '
54071 = '54071'
54073 = '54073'
54075 = '54075'
54077 = '54077'
54079 = '1480 '
54081 = '54081'
54083 = '54083'
54085 = '54085'
54087 = '54087'
54089 = '54089'
54091 = '54091'
54093 = '54093'
54095 = '54095'
54097 = '54097'
54099 = '3400 '
54101 = '54101'
54103 = '54103'
54105 = '54105'
54107 = '6020 '
54109 = '54109'
55000 = '55000'
55001 = '55001'
55003 = '55003'
55005 = '55005'
55007 = '55007'
55009 = '3080 '
55011 = '55011'
55013 = '55013'
55015 = '0460 '
55017 = '2290 '
55019 = '55019'
55021 = '55021'
55023 = '55023'
55025 = '4720 '
55027 = '55027'
55029 = '55029'
55031 = '2240 '
55033 = '55033'
55035 = '2290 '
55037 = '55037'
55039 = '55039'
55041 = '55041'
55043 = '55043'
55045 = '55045'
55047 = '55047'
55049 = '55049'
55051 = '55051'
55053 = '55053'
55055 = '55055'
55057 = '55057'
55059 = '1602 '
55061 = '55061'
55063 = '3870 '
55065 = '55065'
55067 = '55067'
55069 = '55069'
55071 = '55071'
55073 = '8940 '
55075 = '55075'
55077 = '55077'
55078 = '55078'
55079 = '5082 '
55081 = '55081'
55083 = '55083'
55085 = '55085'
55087 = '0460 '
55089 = '5082 '
55091 = '55091'
55093 = '5120 '
55095 = '55095'
55097 = '55097'
55099 = '55099'
55101 = '5082 '
55103 = '55103'
55105 = '3620 '
55107 = '55107'
55109 = '5120 '
55111 = '55111'
55113 = '55113'
55115 = '55115'
55117 = '7620 '
55119 = '55119'
55121 = '55121'
55123 = '55123'
55125 = '55125'
55127 = '55127'
55129 = '55129'
55131 = '5082 '
55133 = '5082 '
55135 = '55135'
55137 = '55137'
55139 = '0460 '
55141 = '55141'
56000 = '56000'
56001 = '56001'
56003 = '56003'
56005 = '56005'
56007 = '56007'
56009 = '56009'
56011 = '56011'
56013 = '56013'
56015 = '56015'
56017 = '56017'
56019 = '56019'
56021 = '1580 '
56023 = '56023'
56025 = '1350 '
56027 = '56027'
56029 = '56029'
56031 = '56031'
56033 = '56033'
56035 = '56035'
56037 = '56037'
56039 = '56039'
56041 = '56041'
56043 = '56043'
56045 = '56045'
OTHER = '     '
;

/*============================================================================;
*  Title:
*          Format Library for Inpatient Quality Indicators
*
*  Description:
*          COVARIATE FORMAT LIB FOR AHRQ INPATIENT QUALITY INDICATORS;
*
*                 >>>  VERSION 2.1  <<<
*
*============================================================================;*/

 /* -------------------------------------------------------------- */
 /* ---   FORMAT FOR AGE STRATIFIERS                           --- */
 /* ---   MODULE 3. ASSIGNS ARRAY INDEX FOR AGE CATEGORIES     --- */
 /* -------------------------------------------------------------- */

VALUE AGEFMT
low - 4 = 1
 5 -  9 = 2
10 - 14 = 3
15 - 17 = 4
18 - 24 = 5
25 - 29 = 6
30 - 34 = 7
35 - 39 = 8
40 - 44 = 9
45 - 49 = 10
50 - 54 = 11
55 - 59 = 12
60 - 64 = 13
65 - 69 = 14
70 - 74 = 15
75 - 79 = 16
80 - 84 = 17
85 - high = 18;

 /* -------------------------------------------------------------- */
 /* ---   FORMATS FOR AGE STRATIFIERS                          --- */
 /* ---   ONE FORMAT PER QI.  NUMBER REFERS TO N VARIABLE IN   --- */
 /* ---   MODULE 3. ASSIGNS ARRAY INDEX FOR AGE CATEGORIES     --- */
 /* -------------------------------------------------------------- */

Value A8FMT
45 - 49 = '1'
50 - 54 = '2'
55 - 59 = '3'
60 - 64 = '4'
65 - 69 = '0'
70 - 74 = '5'
75 - 79 = '6'
other  = '7'
;

Value A9FMT
45 - 49 = '1'
50 - 54 = '2'
55 - 59 = '3'
60 - 64 = '4'
65 - 69 = '5'
70 - 74 = '0'
75 - 79 = '6'
80 - 84 = '7'
other  = '8'
;

Value A10FMT
low - 4 = '0'
5   - 9 = '1'
10 - 14 = '2'
other  = '3'
;

Value A11FMT
60 - 64 = '1'
65 - 69 = '2'
70 - 74 = '0'
75 - 79 = '3'
80 - 84 = '4'
85 - high = '5'
other  = '6'
;

Value A12FMT
50 - 54 = '1'
55 - 59 = '2'
60 - 64 = '3'
65 - 69 = '4'
70 - 74 = '0'
75 - 79 = '5'
80 - 84 = '6'
other  = '7'
;

Value A13FMT
18 - 24 = '1'
25 - 29 = '2'
30 - 34 = '3'
35 - 39 = '4'
40 - 44 = '5'
45 - 49 = '6'
50 - 54 = '7'
55 - 59 = '8'
60 - 64 = '9'
65 - 69 = '10'
70 - 74 = '0'
75 - 79 = '11'
80 - 84 = '12'
other  = '13'
;

Value A14FMT
50 - 54 = '1'
55 - 59 = '2'
60 - 64 = '3'
65 - 69 = '4'
70 - 74 = '0'
75 - 79 = '5'
80 - 84 = '6'
85 - high = '7'
other  = '8'
;

Value A15FMT
45 - 49 = '1'
50 - 54 = '2'
55 - 59 = '3'
60 - 64 = '4'
65 - 69 = '5'
70 - 74 = '6'
75 - 79 = '0'
80 - 84 = '7'
85 - high = '8'
other  = '9'
;

Value A16FMT
55 - 59 = '1'
60 - 64 = '2'
65 - 69 = '3'
70 - 74 = '4'
75 - 79 = '5'
80 - 84 = '6'
85 - high = '0'
other  = '7'
;

Value A17FMT
50 - 54 = '1'
55 - 59 = '2'
60 - 64 = '3'
65 - 69 = '4'
70 - 74 = '5'
75 - 79 = '6'
80 - 84 = '7'
85 - high = '0'
other  = '8'
;

Value A18FMT
40 - 44 = '1'
45 - 49 = '2'
50 - 54 = '3'
55 - 59 = '4'
60 - 64 = '5'
65 - 69 = '6'
70 - 74 = '7'
75 - 79 = '8'
80 - 84 = '9'
85 - high = '0'
other  = '10'
;

Value A19FMT
65 - 69 = '1'
70 - 74 = '2'
75 - 79 = '3'
80 - 84 = '4'
85 - high = '0'
other  = '5'
;

Value A20FMT
40 - 44 = '1'
45 - 49 = '2'
50 - 54 = '3'
55 - 59 = '4'
60 - 64 = '5'
65 - 69 = '6'
70 - 74 = '7'
75 - 79 = '8'
80 - 84 = '9'
85 - high = '0'
other  = '10'
;

Value A21FMT
18 - 24 = '0'
25 - 29 = '1'
30 - 34 = '2'
35 - 39 = '3'
other  = '4'
;

Value A22FMT
18 - 24 = '1'
25 - 29 = '2'
30 - 34 = '0'
35 - 39 = '3'
other  = '4'
;

Value A23FMT
25 - 29 = '1'
30 - 34 = '2'
35 - 39 = '3'
40 - 44 = '4'
45 - 49 = '5'
50 - 54 = '6'
55 - 59 = '7'
60 - 64 = '8'
65 - 69 = '9'
70 - 74 = '0'
75 - 79 = '10'
80 - 84 = '11'
other  = '12'
;

Value A24FMT
65 - 69 = '1'
70 - 74 = '0'
75 - 79 = '2'
80 - 84 = '3'
other  = '4'
;

Value A25FMT
45 - 49 = '1'
50 - 54 = '2'
55 - 59 = '3'
60 - 64 = '4'
65 - 69 = '5'
70 - 74 = '0'
75 - 79 = '6'
80 - 84 = '7'
other  = '8'
;

Value A26FMT
low - 4 =  '1'
 5 -  9 =  '2'
10 - 14 =  '3'
15 - 17 =  '4'
18 - 24 =  '5'
25 - 29 =  '6'
30 - 34 =  '7'
35 - 39 =  '8'
40 - 44 =  '9'
45 - 49 = '10'
50 - 54 = '11'
55 - 59 =  '0'
60 - 64 = '13'
65 - 69 = '14'
70 - 74 = '15'
75 - 79 = '16'
80 - 84 = '17'
85 - high = '18'
;

Value A27FMT
low - 4 =  '1'
 5 -  9 =  '2'
10 - 14 =  '3'
15 - 17 =  '4'
18 - 24 =  '5'
25 - 29 =  '6'
30 - 34 =  '7'
35 - 39 =  '8'
40 - 44 =  '9'
45 - 49 = '10'
50 - 54 =  '0'
55 - 59 = '12'
60 - 64 = '13'
65 - 69 = '14'
70 - 74 = '15'
75 - 79 = '16'
80 - 84 = '17'
85 - high = '18';

Value A28FMT
low - 4 =  '1'
 5 -  9 =  '2'
10 - 14 =  '3'
15 - 17 =  '4'
18 - 24 =  '5'
25 - 29 =  '6'
30 - 34 =  '7'
35 - 39 =  '8'
40 - 44 =  '0'
45 - 49 = '10'
50 - 54 = '11'
55 - 59 = '12'
60 - 64 = '13'
65 - 69 = '14'
70 - 74 = '15'
75 - 79 = '16'
80 - 84 = '17'
85 - high = '18';

Value A29FMT
low - 4 =  '1'
 5 -  9 =  '2'
10 - 14 =  '3'
15 - 17 =  '4'
18 - 24 =  '5'
25 - 29 =  '6'
30 - 34 =  '7'
35 - 39 =  '8'
40 - 44 =  '0'
45 - 49 = '10'
50 - 54 = '11'
55 - 59 = '12'
60 - 64 = '13'
65 - 69 = '14'
70 - 74 = '15'
75 - 79 = '16'
80 - 84 = '17'
85 - high = '18';

Value A30FMT
45 - 49 = '1'
50 - 54 = '2'
55 - 59 = '3'
60 - 64 = '4'
65 - 69 = '5'
70 - 74 = '0'
75 - 79 = '6'
80 - 84 = '7'
other  = '8'
;

Value A31FMT
55 - 59 = '1'
60 - 64 = '2'
65 - 69 = '3'
70 - 74 = '0'
75 - 79 = '4'
80 - 84 = '5'
other  = '6'
;

 /* -------------------------------------------------------------- */
 /* --- V15 FORMATS FOR APR-DRG STRATIFIERS ---------------------- */
 /* ---   ONE FORMAT PER IQI.  NUMBER REFERS TO N VARIABLE IN  --- */
 /* ---   PROGRAM P3. ASSIGNS ARRAY INDEX FOR APR-DRG          --- */
 /* ---   CATEGORIES (PROVIDER ONLY).                          --- */
 /* -------------------------------------------------------------- */

Value $C8FMT
'2201' = '0'
'2202' = '1'
'2203' = '2'
'2204' = '3'
other = '4';

Value $C9FMT
'2601' = '0'
'2602' = '1'
'2603' = '2'
'2604' = '3'
other = '4';

Value $C10FMT
'1671' = '0'
'1672' = '1'
'1673' = '2'
'1674' = '3'
'1601' = '4'
'1602' = '5'
'1603' = '6'
'1604' = '7'
'6301' = '8'
'6302' = '9'
'6303' = '10'
'6304' = '11'
'1631' = '12'
'1632' = '13'
'1633' = '14'
'1634' = '15'
'1681' = '16'
'1682' = '17'
'1683' = '18'
'1684' = '19'
other = '20';

Value $C11FMT
'1691' = '0'
'1692' = '1'
'1693' = '2'
'1694' = '3'
'1681' = '4'
'1682' = '5'
'1683' = '6'
'1684' = '7'
other = '8';

Value $C12FMT
'1651' = '0'
'1652' = '1'
'1653' = '2'
'1654' = '3'
'1661' = '4'
'1662' = '5'
'1663' = '6'
'1664' = '7'
'1631' = '8'
'1632' = '9'
'1633' = '10'
'1634' = '11'
other = '12';

Value $C13FMT
'0211' = '0'
'0212' = '1'
'0213' = '2'
'0214' = '3'
'0221' = '4'
'0222' = '5'
'0223' = '6'
'0224' = '7'
other = '8';

Value $C14FMT
'3021' = '0'
'3022' = '1'
'3023' = '2'
'3024' = '3'
other = '4';

Value $C15FMT
'1901' = '0'
'1902' = '1'
'1903' = '2'
'1904' = '3'
'1741' = '4'
'1742' = '5'
'1743' = '6'
'1744' = '7'
'1651' = '8'
'1652' = '9'
'1653' = '10'
'1654' = '11'
'1661' = '12'
'1662' = '13'
'1663' = '14'
'1664' = '15'
'1731' = '16'
'1732' = '17'
'1733' = '18'
'1734' = '19'
'0041' = '20'
'0042' = '21'
'0043' = '22'
'0044' = '23'
'1701' = '24'
'1702' = '25'
'1703' = '26'
'1704' = '27'
other = '28';

Value $C16FMT
'1941' = '0'
'1942' = '1'
'1943' = '2'
'1944' = '3'
other = '4';

Value $C17FMT
'0451' = '0'
'0452' = '1'
'0453' = '2'
'0454' = '3'
'0461' = '4'
'0462' = '5'
'0463' = '6'
'0464' = '7'
'0441' = '8'
'0442' = '9'
'0443' = '10'
'0444' = '11'
other = '12';

Value $C18FMT
'2411' = '0'
'2412' = '1'
'2413' = '2'
'2414' = '3'
'2501' = '4'
'2502' = '5'
'2503' = '6'
'2504' = '7'
'2441' = '8'
'2442' = '9'
'2443' = '10'
'2444' = '11'
'2421' = '12'
'2422' = '13'
'2423' = '14'
'2424' = '15'
other = '16';

Value $C19FMT
'3081' = '0'
'3082' = '1'
'3083' = '2'
'3084' = '3'
'3011' = '4'
'3012' = '5'
'3013' = '6'
'3014' = '7'
'3401' = '8'
'3402' = '9'
'3403' = '10'
'3404' = '11'
other = '12';

Value $C20FMT
'1391' = '0'
'1392' = '1'
'1393' = '2'
'1394' = '3'
'1371' = '4'
'1372' = '5'
'1373' = '6'
'1374' = '7'
other = '8';

Value $C21FMT
other = '0';

Value $C22FMT
other = '0';

Value $C23FMT
other = '0';

Value $C24FMT
'2211' = '0'
'2212' = '1'
'2213' = '2'
'2214' = '3'
'5131' = '4'
'5132' = '5'
'5133' = '6'
'5134' = '7'
'2621' = '8'
'2622' = '9'
'2623' = '10'
'2624' = '11'
'2201' = '12'
'2202' = '13'
'2203' = '14'
'2204' = '15'
'5141' = '16'
'5142' = '17'
'5143' = '18'
'5144' = '19'
'2241' = '20'
'2242' = '21'
'2243' = '22'
'2244' = '23'
'5121' = '24'
'5122' = '25'
'5123' = '26'
'5124' = '27'
'2231' = '28'
'2232' = '29'
'2233' = '30'
'2234' = '31'
'2291' = '32'
'2292' = '33'
'2293' = '34'
'2294' = '35'
other = '36';

Value $C25FMT
'1921' = '0'
'1922' = '1'
'1923' = '2'
'1924' = '3'
'1751' = '4'
'1752' = '5'
'1753' = '6'
'1754' = '7'
'1651' = '8'
'1652' = '9'
'1653' = '10'
'1654' = '11'
'1901' = '12'
'1902' = '13'
'1903' = '14'
'1904' = '15'
'1741' = '16'
'1742' = '17'
'1743' = '18'
'1744' = '19'
'1911' = '20'
'1912' = '21'
'1913' = '22'
'1914' = '23'
other = '24';

Value $C30FMT
'1751' = '0'
'1752' = '1'
'1753' = '2'
'1754' = '3'
'1741' = '4'
'1742' = '5'
'1743' = '6'
'1744' = '7'
other = '8';

Value $C31FMT
'0241' = '0'
'0242' = '1'
'0243' = '2'
'0244' = '3'
other = '4';

RUN;
